"""
Python module generated from Java source file org.bukkit.entity.Boat

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import TreeSpecies
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Boat(Vehicle):
    """
    Represents a boat entity.
    """

    def getWoodType(self) -> "TreeSpecies":
        """
        Gets the wood type of the boat.

        Returns
        - the wood type
        """
        ...


    def setWoodType(self, species: "TreeSpecies") -> None:
        """
        Sets the wood type of the boat.

        Arguments
        - species: the new wood type
        """
        ...


    def getMaxSpeed(self) -> float:
        """
        Gets the maximum speed of a boat. The speed is unrelated to the
        velocity.

        Returns
        - The max speed.

        Deprecated
        - boats are complex and many of these methods do not work correctly across multiple versions.
        """
        ...


    def setMaxSpeed(self, speed: float) -> None:
        """
        Sets the maximum speed of a boat. Must be nonnegative. Default is 0.4D.

        Arguments
        - speed: The max speed.

        Deprecated
        - boats are complex and many of these methods do not work correctly across multiple versions.
        """
        ...


    def getOccupiedDeceleration(self) -> float:
        """
        Gets the deceleration rate (newSpeed = curSpeed * rate) of occupied
        boats. The default is 0.2.

        Returns
        - The rate of deceleration

        Deprecated
        - boats are complex and many of these methods do not work correctly across multiple versions.
        """
        ...


    def setOccupiedDeceleration(self, rate: float) -> None:
        """
        Sets the deceleration rate (newSpeed = curSpeed * rate) of occupied
        boats. Setting this to a higher value allows for quicker acceleration.
        The default is 0.2.

        Arguments
        - rate: deceleration rate

        Deprecated
        - boats are complex and many of these methods do not work correctly across multiple versions.
        """
        ...


    def getUnoccupiedDeceleration(self) -> float:
        """
        Gets the deceleration rate (newSpeed = curSpeed * rate) of unoccupied
        boats. The default is -1. Values below 0 indicate that no additional
        deceleration is imposed.

        Returns
        - The rate of deceleration

        Deprecated
        - boats are complex and many of these methods do not work correctly across multiple versions.
        """
        ...


    def setUnoccupiedDeceleration(self, rate: float) -> None:
        """
        Sets the deceleration rate (newSpeed = curSpeed * rate) of unoccupied
        boats. Setting this to a higher value allows for quicker deceleration
        of boats when a player disembarks. The default is -1. Values below 0
        indicate that no additional deceleration is imposed.

        Arguments
        - rate: deceleration rate

        Deprecated
        - boats are complex and many of these methods do not work correctly across multiple versions.
        """
        ...


    def getWorkOnLand(self) -> bool:
        """
        Get whether boats can work on land.

        Returns
        - whether boats can work on land

        Deprecated
        - boats are complex and many of these methods do not work correctly across multiple versions.
        """
        ...


    def setWorkOnLand(self, workOnLand: bool) -> None:
        """
        Set whether boats can work on land.

        Arguments
        - workOnLand: whether boats can work on land

        Deprecated
        - boats are complex and many of these methods do not work correctly across multiple versions.
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.WrappingScheduledExecutorService

Java source file obtained from artifact guava version 31.0.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.util.concurrent import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util.concurrent import Callable
from java.util.concurrent import ScheduledExecutorService
from java.util.concurrent import ScheduledFuture
from java.util.concurrent import TimeUnit
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class WrappingScheduledExecutorService(WrappingExecutorService, ScheduledExecutorService):
    """
    An abstract `ScheduledExecutorService` that allows subclasses to .wrapTask(Callable) wrap tasks before they are submitted to the underlying executor.
    
    Note that task wrapping may occur even if the task is never executed.

    Author(s)
    - Luke Sandberg
    """

    def schedule(self, command: "Runnable", delay: int, unit: "TimeUnit") -> "ScheduledFuture"[Any]:
        ...


    def schedule(self, task: "Callable"["V"], delay: int, unit: "TimeUnit") -> "ScheduledFuture"["V"]:
        ...


    def scheduleAtFixedRate(self, command: "Runnable", initialDelay: int, period: int, unit: "TimeUnit") -> "ScheduledFuture"[Any]:
        ...


    def scheduleWithFixedDelay(self, command: "Runnable", initialDelay: int, delay: int, unit: "TimeUnit") -> "ScheduledFuture"[Any]:
        ...



"""
Python module generated from Java source file org.bukkit.configuration.MemorySection

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Collections
from java.util import LinkedHashSet
from org.apache.commons.lang import Validate
from org.bukkit import Color
from org.bukkit import Location
from org.bukkit import OfflinePlayer
from org.bukkit.configuration import *
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.inventory import ItemStack
from org.bukkit.util import Vector
from typing import Any, Callable, Iterable, Tuple


class MemorySection(ConfigurationSection):
    """
    A type of ConfigurationSection that is stored in memory.
    """

    def getKeys(self, deep: bool) -> set[str]:
        ...


    def getValues(self, deep: bool) -> dict[str, "Object"]:
        ...


    def contains(self, path: str) -> bool:
        ...


    def contains(self, path: str, ignoreDefault: bool) -> bool:
        ...


    def isSet(self, path: str) -> bool:
        ...


    def getCurrentPath(self) -> str:
        ...


    def getName(self) -> str:
        ...


    def getRoot(self) -> "Configuration":
        ...


    def getParent(self) -> "ConfigurationSection":
        ...


    def addDefault(self, path: str, value: "Object") -> None:
        ...


    def getDefaultSection(self) -> "ConfigurationSection":
        ...


    def set(self, path: str, value: "Object") -> None:
        ...


    def get(self, path: str) -> "Object":
        ...


    def get(self, path: str, def: "Object") -> "Object":
        ...


    def createSection(self, path: str) -> "ConfigurationSection":
        ...


    def createSection(self, path: str, map: dict[Any, Any]) -> "ConfigurationSection":
        ...


    def getString(self, path: str) -> str:
        ...


    def getString(self, path: str, def: str) -> str:
        ...


    def isString(self, path: str) -> bool:
        ...


    def getInt(self, path: str) -> int:
        ...


    def getInt(self, path: str, def: int) -> int:
        ...


    def isInt(self, path: str) -> bool:
        ...


    def getBoolean(self, path: str) -> bool:
        ...


    def getBoolean(self, path: str, def: bool) -> bool:
        ...


    def isBoolean(self, path: str) -> bool:
        ...


    def getDouble(self, path: str) -> float:
        ...


    def getDouble(self, path: str, def: float) -> float:
        ...


    def isDouble(self, path: str) -> bool:
        ...


    def getLong(self, path: str) -> int:
        ...


    def getLong(self, path: str, def: int) -> int:
        ...


    def isLong(self, path: str) -> bool:
        ...


    def getList(self, path: str) -> list[Any]:
        ...


    def getList(self, path: str, def: list[Any]) -> list[Any]:
        ...


    def isList(self, path: str) -> bool:
        ...


    def getStringList(self, path: str) -> list[str]:
        ...


    def getIntegerList(self, path: str) -> list["Integer"]:
        ...


    def getBooleanList(self, path: str) -> list["Boolean"]:
        ...


    def getDoubleList(self, path: str) -> list["Double"]:
        ...


    def getFloatList(self, path: str) -> list["Float"]:
        ...


    def getLongList(self, path: str) -> list["Long"]:
        ...


    def getByteList(self, path: str) -> list["Byte"]:
        ...


    def getCharacterList(self, path: str) -> list["Character"]:
        ...


    def getShortList(self, path: str) -> list["Short"]:
        ...


    def getMapList(self, path: str) -> list[dict[Any, Any]]:
        ...


    def getObject(self, path: str, clazz: type["T"]) -> "T":
        ...


    def getObject(self, path: str, clazz: type["T"], def: "T") -> "T":
        ...


    def getSerializable(self, path: str, clazz: type["T"]) -> "T":
        ...


    def getSerializable(self, path: str, clazz: type["T"], def: "T") -> "T":
        ...


    def getVector(self, path: str) -> "Vector":
        ...


    def getVector(self, path: str, def: "Vector") -> "Vector":
        ...


    def isVector(self, path: str) -> bool:
        ...


    def getOfflinePlayer(self, path: str) -> "OfflinePlayer":
        ...


    def getOfflinePlayer(self, path: str, def: "OfflinePlayer") -> "OfflinePlayer":
        ...


    def isOfflinePlayer(self, path: str) -> bool:
        ...


    def getItemStack(self, path: str) -> "ItemStack":
        ...


    def getItemStack(self, path: str, def: "ItemStack") -> "ItemStack":
        ...


    def isItemStack(self, path: str) -> bool:
        ...


    def getColor(self, path: str) -> "Color":
        ...


    def getColor(self, path: str, def: "Color") -> "Color":
        ...


    def isColor(self, path: str) -> bool:
        ...


    def getLocation(self, path: str) -> "Location":
        ...


    def getLocation(self, path: str, def: "Location") -> "Location":
        ...


    def isLocation(self, path: str) -> bool:
        ...


    def getConfigurationSection(self, path: str) -> "ConfigurationSection":
        ...


    def isConfigurationSection(self, path: str) -> bool:
        ...


    @staticmethod
    def createPath(section: "ConfigurationSection", key: str) -> str:
        """
        Creates a full path to the given ConfigurationSection from its
        root Configuration.
        
        You may use this method for any given ConfigurationSection, not
        only MemorySection.

        Arguments
        - section: Section to create a path for.
        - key: Name of the specified section.

        Returns
        - Full path of the section from its root.
        """
        ...


    @staticmethod
    def createPath(section: "ConfigurationSection", key: str, relativeTo: "ConfigurationSection") -> str:
        """
        Creates a relative path to the given ConfigurationSection from
        the given relative section.
        
        You may use this method for any given ConfigurationSection, not
        only MemorySection.

        Arguments
        - section: Section to create a path for.
        - key: Name of the specified section.
        - relativeTo: Section to create the path relative to.

        Returns
        - Full path of the section from its root.
        """
        ...


    def getComments(self, path: str) -> list[str]:
        ...


    def getInlineComments(self, path: str) -> list[str]:
        ...


    def setComments(self, path: str, comments: list[str]) -> None:
        ...


    def setInlineComments(self, path: str, comments: list[str]) -> None:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.external.com.google.gdata.util.common.base.Escaper

Java source file obtained from artifact snakeyaml version 1.30

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.external.com.google.gdata.util.common.base import *
from typing import Any, Callable, Iterable, Tuple


class Escaper:
    """
    An object that converts literal text into a format safe for inclusion in a
    particular context (such as an XML document). Typically (but not always), the
    inverse process of "unescaping" the text is performed automatically by the
    relevant parser.
    
    
    For example, an XML escaper would convert the literal string
    `"Foo<Bar>"` into `"Foo&lt;Bar&gt;"` to prevent `"<Bar>"`
    from being confused with an XML tag. When the resulting XML document is
    parsed, the parser API will return this text as the original literal string
    `"Foo<Bar>"`.
    
    
    An `Escaper` instance is required to be stateless, and safe when used
    concurrently by multiple threads.
    
    
    Several popular escapers are defined as constants in the class
    CharEscapers. To create your own escapers, use
    CharEscaperBuilder, or extend CharEscaper or
    `UnicodeEscaper`.
    """

    def escape(self, string: str) -> str:
        """
        Returns the escaped form of a given literal string.
        
        
        Note that this method may treat input characters differently depending on
        the specific escaper implementation.
        
        - UnicodeEscaper handles <a
        href="http://en.wikipedia.org/wiki/UTF-16">UTF-16</a> correctly,
        including surrogate character pairs. If the input is badly formed the
        escaper should throw IllegalArgumentException.
        - CharEscaper handles Java characters independently and does
        not verify the input for well formed characters. A CharEscaper should not
        be used in situations where input is not guaranteed to be restricted to
        the Basic Multilingual Plane (BMP).

        Arguments
        - string: the literal string to be escaped

        Returns
        - the escaped form of `string`

        Raises
        - NullPointerException: if `string` is null
        - IllegalArgumentException: if `string` contains badly formed UTF-16 or cannot be
                    escaped for any other reason
        """
        ...


    def escape(self, out: "Appendable") -> "Appendable":
        """
        Returns an `Appendable` instance which automatically escapes all
        text appended to it before passing the resulting text to an underlying
        `Appendable`.
        
        
        Note that this method may treat input characters differently depending on
        the specific escaper implementation.
        
        - UnicodeEscaper handles <a
        href="http://en.wikipedia.org/wiki/UTF-16">UTF-16</a> correctly,
        including surrogate character pairs. If the input is badly formed the
        escaper should throw IllegalArgumentException.
        - CharEscaper handles Java characters independently and does
        not verify the input for well formed characters. A CharEscaper should not
        be used in situations where input is not guaranteed to be restricted to
        the Basic Multilingual Plane (BMP).

        Arguments
        - out: the underlying `Appendable` to append escaped output to

        Returns
        - an `Appendable` which passes text to `out` after
                escaping it.
        """
        ...



from .ImmutableNetwork import ImmutableNetwork
from .MutableValueGraph import MutableValueGraph
from .ForwardingNetwork import ForwardingNetwork
from .StandardValueGraph import StandardValueGraph
from .EndpointPair import EndpointPair
from .ParametricNullness import ParametricNullness
from .NetworkBuilder import NetworkBuilder
from .UndirectedGraphConnections import UndirectedGraphConnections
from .NetworkConnections import NetworkConnections
from .BaseGraph import BaseGraph
from .UndirectedMultiNetworkConnections import UndirectedMultiNetworkConnections
from .ImmutableGraph import ImmutableGraph
from .ForwardingValueGraph import ForwardingValueGraph
from .AbstractGraphBuilder import AbstractGraphBuilder
from .StandardMutableGraph import StandardMutableGraph
from .AbstractNetwork import AbstractNetwork
from .AbstractDirectedNetworkConnections import AbstractDirectedNetworkConnections
from .ElementTypesAreNonnullByDefault import ElementTypesAreNonnullByDefault
from .Graph import Graph
from .ForwardingGraph import ForwardingGraph
from .DirectedNetworkConnections import DirectedNetworkConnections
from .MutableGraph import MutableGraph
from .AbstractBaseGraph import AbstractBaseGraph
from .Network import Network
from .EndpointPairIterator import EndpointPairIterator
from .MapRetrievalCache import MapRetrievalCache
from .IncidentEdgeSet import IncidentEdgeSet
from .MapIteratorCache import MapIteratorCache
from .Graphs import Graphs
from .PredecessorsFunction import PredecessorsFunction
from .AbstractGraph import AbstractGraph
from .ValueGraphBuilder import ValueGraphBuilder
from .ImmutableValueGraph import ImmutableValueGraph
from .DirectedMultiNetworkConnections import DirectedMultiNetworkConnections
from .EdgesConnecting import EdgesConnecting
from .DirectedGraphConnections import DirectedGraphConnections
from .Traverser import Traverser
from .ElementOrder import ElementOrder
from .StandardMutableNetwork import StandardMutableNetwork
from .SuccessorsFunction import SuccessorsFunction
from .ValueGraph import ValueGraph
from .UndirectedNetworkConnections import UndirectedNetworkConnections
from .GraphBuilder import GraphBuilder
from .GraphConnections import GraphConnections
from .AbstractValueGraph import AbstractValueGraph
from .GraphConstants import GraphConstants
from .MultiEdgesConnecting import MultiEdgesConnecting
from .AbstractUndirectedNetworkConnections import AbstractUndirectedNetworkConnections
from .StandardNetwork import StandardNetwork
from .MutableNetwork import MutableNetwork
from .StandardMutableValueGraph import StandardMutableValueGraph


"""
Python module generated from Java source file org.bukkit.potion.PotionType

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.potion import *
from typing import Any, Callable, Iterable, Tuple


class PotionType(Enum):
    """
    This enum reflects and matches each potion state that can be obtained from
    the Creative mode inventory
    """

    UNCRAFTABLE = (None, False, False)
    WATER = (None, False, False)
    MUNDANE = (None, False, False)
    THICK = (None, False, False)
    AWKWARD = (None, False, False)
    NIGHT_VISION = (PotionEffectType.NIGHT_VISION, False, True)
    INVISIBILITY = (PotionEffectType.INVISIBILITY, False, True)
    JUMP = (PotionEffectType.JUMP, True, True)
    FIRE_RESISTANCE = (PotionEffectType.FIRE_RESISTANCE, False, True)
    SPEED = (PotionEffectType.SPEED, True, True)
    SLOWNESS = (PotionEffectType.SLOW, True, True)
    WATER_BREATHING = (PotionEffectType.WATER_BREATHING, False, True)
    INSTANT_HEAL = (PotionEffectType.HEAL, True, False)
    INSTANT_DAMAGE = (PotionEffectType.HARM, True, False)
    POISON = (PotionEffectType.POISON, True, True)
    REGEN = (PotionEffectType.REGENERATION, True, True)
    STRENGTH = (PotionEffectType.INCREASE_DAMAGE, True, True)
    WEAKNESS = (PotionEffectType.WEAKNESS, False, True)
    LUCK = (PotionEffectType.LUCK, False, False)
    TURTLE_MASTER = (PotionEffectType.SLOW, True, True)
    SLOW_FALLING = (PotionEffectType.SLOW_FALLING, False, True)


    def getEffectType(self) -> "PotionEffectType":
        ...


    def isInstant(self) -> bool:
        ...


    def isUpgradeable(self) -> bool:
        """
        Checks if the potion type has an upgraded state.
        This refers to whether or not the potion type can be Tier 2,
        such as Potion of Fire Resistance II.

        Returns
        - True if the potion type can be upgraded;
        """
        ...


    def isExtendable(self) -> bool:
        """
        Checks if the potion type has an extended state.
        This refers to the extended duration potions

        Returns
        - True if the potion type can be extended
        """
        ...


    def getMaxLevel(self) -> int:
        ...


    @staticmethod
    def getByEffect(effectType: "PotionEffectType") -> "PotionType":
        """
        Arguments
        - effectType: the effect to get by

        Returns
        - the matching potion type

        Deprecated
        - Misleading
        """
        ...



from .ParametricNullness import ParametricNullness
from .ElementTypesAreNonnullByDefault import ElementTypesAreNonnullByDefault
from .ArrayBasedEscaperMap import ArrayBasedEscaperMap
from .ArrayBasedCharEscaper import ArrayBasedCharEscaper
from .CharEscaperBuilder import CharEscaperBuilder
from .Platform import Platform
from .Escaper import Escaper
from .CharEscaper import CharEscaper
from .Escapers import Escapers
from .UnicodeEscaper import UnicodeEscaper
from .ArrayBasedUnicodeEscaper import ArrayBasedUnicodeEscaper


from .ExecutionSequencer import ExecutionSequencer
from .ForwardingFluentFuture import ForwardingFluentFuture
from .ImmediateFuture import ImmediateFuture
from .AggregateFutureState import AggregateFutureState
from .AtomicDoubleArray import AtomicDoubleArray
from .ListenableFutureTask import ListenableFutureTask
from .ListenerCallQueue import ListenerCallQueue
from .AsyncFunction import AsyncFunction
from .ForwardingListeningExecutorService import ForwardingListeningExecutorService
from .ForwardingExecutorService import ForwardingExecutorService
from .ThreadFactoryBuilder import ThreadFactoryBuilder
from .NullnessCasts import NullnessCasts
from .AbstractListeningExecutorService import AbstractListeningExecutorService
from .AsyncCallable import AsyncCallable
from .TimeLimiter import TimeLimiter
from .ParametricNullness import ParametricNullness
from .SequentialExecutor import SequentialExecutor
from .ClosingFuture import ClosingFuture
from .WrappingExecutorService import WrappingExecutorService
from .ForwardingBlockingQueue import ForwardingBlockingQueue
from .SettableFuture import SettableFuture
from .ServiceManagerBridge import ServiceManagerBridge
from .Internal import Internal
from .Runnables import Runnables
from .CycleDetectingLockFactory import CycleDetectingLockFactory
from .AtomicLongMap import AtomicLongMap
from .UncaughtExceptionHandlers import UncaughtExceptionHandlers
from .FuturesGetChecked import FuturesGetChecked
from .ForwardingListenableFuture import ForwardingListenableFuture
from .Atomics import Atomics
from .Partially import Partially
from .DirectExecutor import DirectExecutor
from .FutureCallback import FutureCallback
from .SmoothRateLimiter import SmoothRateLimiter
from .TimeoutFuture import TimeoutFuture
from .AbstractIdleService import AbstractIdleService
from .ElementTypesAreNonnullByDefault import ElementTypesAreNonnullByDefault
from .GwtFuturesCatchingSpecialization import GwtFuturesCatchingSpecialization
from .TrustedListenableFutureTask import TrustedListenableFutureTask
from .AbstractFuture import AbstractFuture
from .ListenableFuture import ListenableFuture
from .ExecutionError import ExecutionError
from .AbstractService import AbstractService
from .UncheckedTimeoutException import UncheckedTimeoutException
from .ForwardingCondition import ForwardingCondition
from .Service import Service
from .SimpleTimeLimiter import SimpleTimeLimiter
from .ListenableScheduledFuture import ListenableScheduledFuture
from .ForwardingLock import ForwardingLock
from .ForwardingBlockingDeque import ForwardingBlockingDeque
from .Uninterruptibles import Uninterruptibles
from .ServiceManager import ServiceManager
from .ListeningScheduledExecutorService import ListeningScheduledExecutorService
from .ListeningExecutorService import ListeningExecutorService
from .AbstractTransformFuture import AbstractTransformFuture
from .OverflowAvoidingLockSupport import OverflowAvoidingLockSupport
from .InterruptibleTask import InterruptibleTask
from .FakeTimeLimiter import FakeTimeLimiter
from .Platform import Platform
from .FluentFuture import FluentFuture
from .AbstractCatchingFuture import AbstractCatchingFuture
from .Monitor import Monitor
from .AbstractScheduledService import AbstractScheduledService
from .AtomicDouble import AtomicDouble
from .Callables import Callables
from .AbstractExecutionThreadService import AbstractExecutionThreadService
from .Striped import Striped
from .AggregateFuture import AggregateFuture
from .UncheckedExecutionException import UncheckedExecutionException
from .RateLimiter import RateLimiter
from .MoreExecutors import MoreExecutors
from .WrappingScheduledExecutorService import WrappingScheduledExecutorService
from .ForwardingFuture import ForwardingFuture
from .ExecutionList import ExecutionList
from .GwtFluentFutureCatchingSpecialization import GwtFluentFutureCatchingSpecialization
from .JdkFutureAdapters import JdkFutureAdapters
from .Futures import Futures
from .CombinedFuture import CombinedFuture
from .CollectionFuture import CollectionFuture


"""
Python module generated from Java source file com.google.common.util.concurrent.ExecutionSequencer

Java source file obtained from artifact guava version 31.0.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.util.concurrent import *
from java.util.concurrent import Callable
from java.util.concurrent import Executor
from java.util.concurrent.atomic import AtomicReference
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ExecutionSequencer:
    """
    Serializes execution of tasks, somewhat like an "asynchronous `synchronized` block." Each
    .submit enqueued callable will not be submitted to its associated executor until the
    previous callable has returned -- and, if the previous callable was an AsyncCallable, not
    until the `Future` it returned is Future.isDone done (successful, failed, or
    cancelled).
    
    This class has limited support for cancellation and other "early completion":
    
    
      - While calls to `submit` and `submitAsync` return a `Future` that can be
          cancelled, cancellation never propagates to a task that has started to run -- neither to
          the callable itself nor to any `Future` returned by an `AsyncCallable`.
          (However, cancellation can prevent an *unstarted* task from running.) Therefore, the
          next task will wait for any running callable (or pending `Future` returned by an
          `AsyncCallable`) to complete, without interrupting it (and without calling `cancel` on the `Future`). So beware: *Even if you cancel every precededing `Future` returned by this class, the next task may still have to wait.*.
      - Once an `AsyncCallable` returns a `Future`, this class considers that task to
          be "done" as soon as *that* `Future` completes in any way. Notably, a `Future` is "completed" even if it is cancelled while its underlying work continues on a
          thread, an RPC, etc. The `Future` is also "completed" if it fails "early" -- for
          example, if the deadline expires on a `Future` returned from Futures.withTimeout while the `Future` it wraps continues its underlying work. So
          beware: *Your `AsyncCallable` should not complete its `Future` until it is
          safe for the next task to start.*
    
    
    An additional limitation: this class serializes execution of *tasks* but not any
    *listeners* of those tasks.
    
    This class is similar to MoreExecutors.newSequentialExecutor. This class is different
    in a few ways:
    
    
      - Each task may be associated with a different executor.
      - Tasks may be of type `AsyncCallable`.
      - Running tasks *cannot* be interrupted. (Note that `newSequentialExecutor` does
          not return `Future` objects, so it doesn't support interruption directly, either.
          However, utilities that *use* that executor have the ability to interrupt tasks
          running on it. This class, by contrast, does not expose an `Executor` API.)
    
    
    If you don't need the features of this class, you may prefer `newSequentialExecutor` for
    its simplicity and ability to accommodate interruption.

    Since
    - 26.0
    """

    @staticmethod
    def create() -> "ExecutionSequencer":
        """
        Creates a new instance.
        """
        ...


    def submit(self, callable: "Callable"["T"], executor: "Executor") -> "ListenableFuture"["T"]:
        """
        Enqueues a task to run when the previous task (if any) completes.
        
        Cancellation does not propagate from the output future to a callable that has begun to
        execute, but if the output future is cancelled before Callable.call() is invoked,
        Callable.call() will not be invoked.
        """
        ...


    def submitAsync(self, callable: "AsyncCallable"["T"], executor: "Executor") -> "ListenableFuture"["T"]:
        """
        Enqueues a task to run when the previous task (if any) completes.
        
        Cancellation does not propagate from the output future to the future returned from `callable` or a callable that has begun to execute, but if the output future is cancelled before
        AsyncCallable.call() is invoked, AsyncCallable.call() will not be invoked.
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.util.ArrayStack

Java source file obtained from artifact snakeyaml version 1.30

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.util import *
from typing import Any, Callable, Iterable, Tuple


class ArrayStack:

    def __init__(self, initSize: int):
        ...


    def push(self, obj: "T") -> None:
        ...


    def pop(self) -> "T":
        ...


    def isEmpty(self) -> bool:
        ...


    def clear(self) -> None:
        ...



from .EventBus import EventBus
from .Dispatcher import Dispatcher
from .SubscriberExceptionHandler import SubscriberExceptionHandler
from .ParametricNullness import ParametricNullness
from .SubscriberRegistry import SubscriberRegistry
from .ElementTypesAreNonnullByDefault import ElementTypesAreNonnullByDefault
from .Subscriber import Subscriber
from .AllowConcurrentEvents import AllowConcurrentEvents
from .Subscribe import Subscribe
from .DeadEvent import DeadEvent
from .AsyncEventBus import AsyncEventBus
from .SubscriberExceptionContext import SubscriberExceptionContext


from .Predicates import Predicates
from .FinalizablePhantomReference import FinalizablePhantomReference
from .Stopwatch import Stopwatch
from .Throwables import Throwables
from .CaseFormat import CaseFormat
from .CommonMatcher import CommonMatcher
from .NullnessCasts import NullnessCasts
from .FunctionalEquivalence import FunctionalEquivalence
from .JdkPattern import JdkPattern
from .ParametricNullness import ParametricNullness
from .Charsets import Charsets
from .MoreObjects import MoreObjects
from .Functions import Functions
from .ElementTypesAreNonnullByDefault import ElementTypesAreNonnullByDefault
from .SmallCharMatcher import SmallCharMatcher
from .FinalizableSoftReference import FinalizableSoftReference
from .Splitter import Splitter
from .Supplier import Supplier
from .FinalizableWeakReference import FinalizableWeakReference
from .FinalizableReference import FinalizableReference
from .Defaults import Defaults
from .Ticker import Ticker
from .PairwiseEquivalence import PairwiseEquivalence
from .AbstractIterator import AbstractIterator
from .Present import Present
from .Optional import Optional
from .Platform import Platform
from .CommonPattern import CommonPattern
from .Predicate import Predicate
from .ExtraObjectsMethodsForWeb import ExtraObjectsMethodsForWeb
from .Suppliers import Suppliers
from .Enums import Enums
from .Absent import Absent
from .Converter import Converter
from .Strings import Strings
from .PatternCompiler import PatternCompiler
from .Verify import Verify
from .FinalizableReferenceQueue import FinalizableReferenceQueue
from .Java8Compatibility import Java8Compatibility
from .StandardSystemProperty import StandardSystemProperty
from .Ascii import Ascii
from .Joiner import Joiner
from .Objects import Objects
from .Preconditions import Preconditions
from .CharMatcher import CharMatcher
from .Equivalence import Equivalence
from .Function import Function
from .Utf8 import Utf8
from .VerifyException import VerifyException


"""
Python module generated from Java source file org.bukkit.entity.Pose

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Pose(Enum):
    """
    Represents an entity body pose.
    """

    STANDING = 0
    """
    Entity is standing normally.
    """
    FALL_FLYING = 1
    """
    Entity is gliding.
    """
    SLEEPING = 2
    """
    Entity is sleeping.
    """
    SWIMMING = 3
    """
    Entity is swimming.
    """
    SPIN_ATTACK = 4
    """
    Entity is riptiding with a trident.
    """
    SNEAKING = 5
    """
    Entity is sneaking.
    """
    LONG_JUMPING = 6
    """
    Entity is long jumping.
    """
    DYING = 7
    """
    Entity is dead.
    """



"""
Python module generated from Java source file org.bukkit.entity.Firework

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from org.bukkit.inventory.meta import FireworkMeta
from typing import Any, Callable, Iterable, Tuple


class Firework(Projectile):

    def getFireworkMeta(self) -> "FireworkMeta":
        """
        Get a copy of the fireworks meta

        Returns
        - A copy of the current Firework meta
        """
        ...


    def setFireworkMeta(self, meta: "FireworkMeta") -> None:
        """
        Apply the provided meta to the fireworks

        Arguments
        - meta: The FireworkMeta to apply
        """
        ...


    def detonate(self) -> None:
        """
        Cause this firework to explode at earliest opportunity, as if it has no
        remaining fuse.
        """
        ...


    def isShotAtAngle(self) -> bool:
        """
        Gets if the firework was shot at an angle (i.e. from a crossbow).
        
        A firework which was not shot at an angle will fly straight upwards.

        Returns
        - shot at angle status
        """
        ...


    def setShotAtAngle(self, shotAtAngle: bool) -> None:
        """
        Sets if the firework was shot at an angle (i.e. from a crossbow).
        
        A firework which was not shot at an angle will fly straight upwards.

        Arguments
        - shotAtAngle: the new shotAtAngle
        """
        ...



"""
Python module generated from Java source file com.google.common.graph.AbstractNetwork

Java source file obtained from artifact guava version 31.0.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.base import Function
from com.google.common.base import Predicate
from com.google.common.collect import ImmutableSet
from com.google.common.collect import Iterators
from com.google.common.collect import Maps
from com.google.common.collect import Sets
from com.google.common.graph import *
from com.google.common.math import IntMath
from java.util import AbstractSet
from java.util import Iterator
from java.util import Optional
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class AbstractNetwork(Network):
    """
    This class provides a skeletal implementation of Network. It is recommended to extend
    this class rather than implement Network directly.
    
    The methods implemented in this class should not be overridden unless the subclass admits a
    more efficient implementation.
    
    Type `<N>`: Node parameter type
    
    Type `<E>`: Edge parameter type

    Author(s)
    - James Sexton

    Since
    - 20.0
    """

    def asGraph(self) -> "Graph"["N"]:
        ...


    def degree(self, node: "N") -> int:
        ...


    def inDegree(self, node: "N") -> int:
        ...


    def outDegree(self, node: "N") -> int:
        ...


    def adjacentEdges(self, edge: "E") -> set["E"]:
        ...


    def edgesConnecting(self, nodeU: "N", nodeV: "N") -> set["E"]:
        ...


    def edgesConnecting(self, endpoints: "EndpointPair"["N"]) -> set["E"]:
        ...


    def edgeConnecting(self, nodeU: "N", nodeV: "N") -> "Optional"["E"]:
        ...


    def edgeConnecting(self, endpoints: "EndpointPair"["N"]) -> "Optional"["E"]:
        ...


    def edgeConnectingOrNull(self, nodeU: "N", nodeV: "N") -> "E":
        ...


    def edgeConnectingOrNull(self, endpoints: "EndpointPair"["N"]) -> "E":
        ...


    def hasEdgeConnecting(self, nodeU: "N", nodeV: "N") -> bool:
        ...


    def hasEdgeConnecting(self, endpoints: "EndpointPair"["N"]) -> bool:
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...


    def toString(self) -> str:
        """
        Returns a string representation of this network.
        """
        ...



"""
Python module generated from Java source file com.google.gson.JsonArray

Java source file obtained from artifact gson version 2.8.9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from java.math import BigDecimal
from java.math import BigInteger
from java.util import Iterator
from typing import Any, Callable, Iterable, Tuple


class JsonArray(JsonElement, Iterable):
    """
    A class representing an array type in Json. An array is a list of JsonElements each of
    which can be of a different type. This is an ordered list, meaning that the order in which
    elements are added is preserved.

    Author(s)
    - Joel Leitch
    """

    def __init__(self):
        """
        Creates an empty JsonArray.
        """
        ...


    def __init__(self, capacity: int):
        ...


    def deepCopy(self) -> "JsonArray":
        """
        Creates a deep copy of this element and all its children

        Since
        - 2.8.2
        """
        ...


    def add(self, bool: "Boolean") -> None:
        """
        Adds the specified boolean to self.

        Arguments
        - bool: the boolean that needs to be added to the array.
        """
        ...


    def add(self, character: "Character") -> None:
        """
        Adds the specified character to self.

        Arguments
        - character: the character that needs to be added to the array.
        """
        ...


    def add(self, number: "Number") -> None:
        """
        Adds the specified number to self.

        Arguments
        - number: the number that needs to be added to the array.
        """
        ...


    def add(self, string: str) -> None:
        """
        Adds the specified string to self.

        Arguments
        - string: the string that needs to be added to the array.
        """
        ...


    def add(self, element: "JsonElement") -> None:
        """
        Adds the specified element to self.

        Arguments
        - element: the element that needs to be added to the array.
        """
        ...


    def addAll(self, array: "JsonArray") -> None:
        """
        Adds all the elements of the specified array to self.

        Arguments
        - array: the array whose elements need to be added to the array.
        """
        ...


    def set(self, index: int, element: "JsonElement") -> "JsonElement":
        """
        Replaces the element at the specified position in this array with the specified element.
          Element can be null.

        Arguments
        - index: index of the element to replace
        - element: element to be stored at the specified position

        Returns
        - the element previously at the specified position

        Raises
        - IndexOutOfBoundsException: if the specified index is outside the array bounds
        """
        ...


    def remove(self, element: "JsonElement") -> bool:
        """
        Removes the first occurrence of the specified element from this array, if it is present.
        If the array does not contain the element, it is unchanged.

        Arguments
        - element: element to be removed from this array, if present

        Returns
        - True if this array contained the specified element, False otherwise

        Since
        - 2.3
        """
        ...


    def remove(self, index: int) -> "JsonElement":
        """
        Removes the element at the specified position in this array. Shifts any subsequent elements
        to the left (subtracts one from their indices). Returns the element that was removed from
        the array.

        Arguments
        - index: index the index of the element to be removed

        Returns
        - the element previously at the specified position

        Raises
        - IndexOutOfBoundsException: if the specified index is outside the array bounds

        Since
        - 2.3
        """
        ...


    def contains(self, element: "JsonElement") -> bool:
        """
        Returns True if this array contains the specified element.

        Arguments
        - element: whose presence in this array is to be tested

        Returns
        - True if this array contains the specified element.

        Since
        - 2.3
        """
        ...


    def size(self) -> int:
        """
        Returns the number of elements in the array.

        Returns
        - the number of elements in the array.
        """
        ...


    def isEmpty(self) -> bool:
        """
        Returns True if the array is empty

        Returns
        - True if the array is empty
        """
        ...


    def iterator(self) -> Iterator["JsonElement"]:
        """
        Returns an iterator to navigate the elements of the array. Since the array is an ordered list,
        the iterator navigates the elements in the order they were inserted.

        Returns
        - an iterator to navigate the elements of the array.
        """
        ...


    def get(self, i: int) -> "JsonElement":
        """
        Returns the ith element of the array.

        Arguments
        - i: the index of the element that is being sought.

        Returns
        - the element present at the ith index.

        Raises
        - IndexOutOfBoundsException: if i is negative or greater than or equal to the
        .size() of the array.
        """
        ...


    def getAsNumber(self) -> "Number":
        """
        convenience method to get this array as a Number if it contains a single element.

        Returns
        - get this element as a number if it is single element array.

        Raises
        - ClassCastException: if the element in the array is of not a JsonPrimitive and
        is not a valid Number.
        - IllegalStateException: if the array has more than one element.
        """
        ...


    def getAsString(self) -> str:
        """
        convenience method to get this array as a String if it contains a single element.

        Returns
        - get this element as a String if it is single element array.

        Raises
        - ClassCastException: if the element in the array is of not a JsonPrimitive and
        is not a valid String.
        - IllegalStateException: if the array has more than one element.
        """
        ...


    def getAsDouble(self) -> float:
        """
        convenience method to get this array as a double if it contains a single element.

        Returns
        - get this element as a double if it is single element array.

        Raises
        - ClassCastException: if the element in the array is of not a JsonPrimitive and
        is not a valid double.
        - IllegalStateException: if the array has more than one element.
        """
        ...


    def getAsBigDecimal(self) -> "BigDecimal":
        """
        convenience method to get this array as a BigDecimal if it contains a single element.

        Returns
        - get this element as a BigDecimal if it is single element array.

        Raises
        - ClassCastException: if the element in the array is of not a JsonPrimitive.
        - NumberFormatException: if the element at index 0 is not a valid BigDecimal.
        - IllegalStateException: if the array has more than one element.

        Since
        - 1.2
        """
        ...


    def getAsBigInteger(self) -> "BigInteger":
        """
        convenience method to get this array as a BigInteger if it contains a single element.

        Returns
        - get this element as a BigInteger if it is single element array.

        Raises
        - ClassCastException: if the element in the array is of not a JsonPrimitive.
        - NumberFormatException: if the element at index 0 is not a valid BigInteger.
        - IllegalStateException: if the array has more than one element.

        Since
        - 1.2
        """
        ...


    def getAsFloat(self) -> float:
        """
        convenience method to get this array as a float if it contains a single element.

        Returns
        - get this element as a float if it is single element array.

        Raises
        - ClassCastException: if the element in the array is of not a JsonPrimitive and
        is not a valid float.
        - IllegalStateException: if the array has more than one element.
        """
        ...


    def getAsLong(self) -> int:
        """
        convenience method to get this array as a long if it contains a single element.

        Returns
        - get this element as a long if it is single element array.

        Raises
        - ClassCastException: if the element in the array is of not a JsonPrimitive and
        is not a valid long.
        - IllegalStateException: if the array has more than one element.
        """
        ...


    def getAsInt(self) -> int:
        """
        convenience method to get this array as an integer if it contains a single element.

        Returns
        - get this element as an integer if it is single element array.

        Raises
        - ClassCastException: if the element in the array is of not a JsonPrimitive and
        is not a valid integer.
        - IllegalStateException: if the array has more than one element.
        """
        ...


    def getAsByte(self) -> int:
        ...


    def getAsCharacter(self) -> str:
        ...


    def getAsShort(self) -> int:
        """
        convenience method to get this array as a primitive short if it contains a single element.

        Returns
        - get this element as a primitive short if it is single element array.

        Raises
        - ClassCastException: if the element in the array is of not a JsonPrimitive and
        is not a valid short.
        - IllegalStateException: if the array has more than one element.
        """
        ...


    def getAsBoolean(self) -> bool:
        """
        convenience method to get this array as a boolean if it contains a single element.

        Returns
        - get this element as a boolean if it is single element array.

        Raises
        - ClassCastException: if the element in the array is of not a JsonPrimitive and
        is not a valid boolean.
        - IllegalStateException: if the array has more than one element.
        """
        ...


    def equals(self, o: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...



"""
Python module generated from Java source file org.bukkit.block.CreatureSpawner

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import *
from org.bukkit.entity import EntityType
from typing import Any, Callable, Iterable, Tuple


class CreatureSpawner(TileState):
    """
    Represents a captured state of a creature spawner.
    """

    def getSpawnedType(self) -> "EntityType":
        """
        Get the spawner's creature type.

        Returns
        - The creature type.
        """
        ...


    def setSpawnedType(self, creatureType: "EntityType") -> None:
        """
        Set the spawner's creature type.

        Arguments
        - creatureType: The creature type.
        """
        ...


    def setCreatureTypeByName(self, creatureType: str) -> None:
        """
        Set the spawner mob type.

        Arguments
        - creatureType: The creature type's name.

        Deprecated
        - magic value, use
        .setSpawnedType(org.bukkit.entity.EntityType).
        """
        ...


    def getCreatureTypeName(self) -> str:
        """
        Get the spawner's creature type.

        Returns
        - The creature type's name.

        Deprecated
        - magic value, use .getSpawnedType().
        """
        ...


    def getDelay(self) -> int:
        """
        Get the spawner's delay.
        
        This is the delay, in ticks, until the spawner will spawn its next mob.

        Returns
        - The delay.
        """
        ...


    def setDelay(self, delay: int) -> None:
        """
        Set the spawner's delay.
        
        If set to -1, the spawn delay will be reset to a random value between
        .getMinSpawnDelay and .getMaxSpawnDelay().

        Arguments
        - delay: The delay.
        """
        ...


    def getMinSpawnDelay(self) -> int:
        """
        The minimum spawn delay amount (in ticks).
        
        This value is used when the spawner resets its delay (for any reason).
        It will choose a random number between .getMinSpawnDelay()
        and .getMaxSpawnDelay() for its next .getDelay().
        
        Default value is 200 ticks.

        Returns
        - the minimum spawn delay amount
        """
        ...


    def setMinSpawnDelay(self, delay: int) -> None:
        """
        Set the minimum spawn delay amount (in ticks).

        Arguments
        - delay: the minimum spawn delay amount

        See
        - .getMinSpawnDelay()
        """
        ...


    def getMaxSpawnDelay(self) -> int:
        """
        The maximum spawn delay amount (in ticks).
        
        This value is used when the spawner resets its delay (for any reason).
        It will choose a random number between .getMinSpawnDelay()
        and .getMaxSpawnDelay() for its next .getDelay().
        
        This value **must** be greater than 0 and less than or equal to
        .getMaxSpawnDelay().
        
        Default value is 800 ticks.

        Returns
        - the maximum spawn delay amount
        """
        ...


    def setMaxSpawnDelay(self, delay: int) -> None:
        """
        Set the maximum spawn delay amount (in ticks).
        
        This value **must** be greater than 0, as well as greater than or
        equal to .getMinSpawnDelay()

        Arguments
        - delay: the new maximum spawn delay amount

        See
        - .getMaxSpawnDelay()
        """
        ...


    def getSpawnCount(self) -> int:
        """
        Get how many mobs attempt to spawn.
        
        Default value is 4.

        Returns
        - the current spawn count
        """
        ...


    def setSpawnCount(self, spawnCount: int) -> None:
        """
        Set how many mobs attempt to spawn.

        Arguments
        - spawnCount: the new spawn count
        """
        ...


    def getMaxNearbyEntities(self) -> int:
        """
        Set the new maximum amount of similar entities that are allowed to be
        within spawning range of this spawner.
        
        If more than the maximum number of entities are within range, the spawner
        will not spawn and try again with a new .getDelay().
        
        Default value is 16.

        Returns
        - the maximum number of nearby, similar, entities
        """
        ...


    def setMaxNearbyEntities(self, maxNearbyEntities: int) -> None:
        """
        Set the maximum number of similar entities that are allowed to be within
        spawning range of this spawner.
        
        Similar entities are entities that are of the same EntityType

        Arguments
        - maxNearbyEntities: the maximum number of nearby, similar, entities
        """
        ...


    def getRequiredPlayerRange(self) -> int:
        """
        Get the maximum distance(squared) a player can be in order for this
        spawner to be active.
        
        If this value is less than or equal to 0, this spawner is always active
        (given that there are players online).
        
        Default value is 16.

        Returns
        - the maximum distance(squared) a player can be in order for this
        spawner to be active.
        """
        ...


    def setRequiredPlayerRange(self, requiredPlayerRange: int) -> None:
        """
        Set the maximum distance (squared) a player can be in order for this
        spawner to be active.
        
        Setting this value to less than or equal to 0 will make this spawner
        always active (given that there are players online).

        Arguments
        - requiredPlayerRange: the maximum distance (squared) a player can be
        in order for this spawner to be active.
        """
        ...


    def getSpawnRange(self) -> int:
        """
        Get the radius around which the spawner will attempt to spawn mobs in.
        
        This area is square, includes the block the spawner is in, and is
        centered on the spawner's x,z coordinates - not the spawner itself.
        
        It is 2 blocks high, centered on the spawner's y-coordinate (its bottom);
        thus allowing mobs to spawn as high as its top surface and as low
        as 1 block below its bottom surface.
        
        Default value is 4.

        Returns
        - the spawn range
        """
        ...


    def setSpawnRange(self, spawnRange: int) -> None:
        """
        Set the new spawn range.

        Arguments
        - spawnRange: the new spawn range

        See
        - .getSpawnRange()
        """
        ...



"""
Python module generated from Java source file org.bukkit.Instrument

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import Maps
from enum import Enum
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class Instrument(Enum):

    PIANO = (0x0)
    """
    Piano is the standard instrument for a note block.
    """
    BASS_DRUM = (0x1)
    """
    Bass drum is normally played when a note block is on top of a
    stone-like block.
    """
    SNARE_DRUM = (0x2)
    """
    Snare drum is normally played when a note block is on top of a sandy
    block.
    """
    STICKS = (0x3)
    """
    Sticks are normally played when a note block is on top of a glass
    block.
    """
    BASS_GUITAR = (0x4)
    """
    Bass guitar is normally played when a note block is on top of a wooden
    block.
    """
    FLUTE = (0x5)
    """
    Flute is normally played when a note block is on top of a clay block.
    """
    BELL = (0x6)
    """
    Bell is normally played when a note block is on top of a gold block.
    """
    GUITAR = (0x7)
    """
    Guitar is normally played when a note block is on top of a woolen block.
    """
    CHIME = (0x8)
    """
    Chime is normally played when a note block is on top of a packed ice
    block.
    """
    XYLOPHONE = (0x9)
    """
    Xylophone is normally played when a note block is on top of a bone block.
    """
    IRON_XYLOPHONE = (0xA)
    """
    Iron Xylophone is normally played when a note block is on top of a iron block.
    """
    COW_BELL = (0xB)
    """
    Cow Bell is normally played when a note block is on top of a soul sand block.
    """
    DIDGERIDOO = (0xC)
    """
    Didgeridoo is normally played when a note block is on top of a pumpkin block.
    """
    BIT = (0xD)
    """
    Bit is normally played when a note block is on top of a emerald block.
    """
    BANJO = (0xE)
    """
    Banjo is normally played when a note block is on top of a hay block.
    """
    PLING = (0xF)
    """
    Pling is normally played when a note block is on top of a glowstone block.
    """


    def getType(self) -> int:
        """
        Returns
        - The type ID of this instrument.

        Deprecated
        - Magic value
        """
        ...


    @staticmethod
    def getByType(type: int) -> "Instrument":
        """
        Get an instrument by its type ID.

        Arguments
        - type: The type ID

        Returns
        - The instrument

        Deprecated
        - Magic value
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.external.com.google.gdata.util.common.base.PercentEscaper

Java source file obtained from artifact snakeyaml version 1.30

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.external.com.google.gdata.util.common.base import *
from typing import Any, Callable, Iterable, Tuple


class PercentEscaper(UnicodeEscaper):
    """
    A `UnicodeEscaper` that escapes some set of Java characters using the
    URI percent encoding scheme. The set of safe characters (those which remain
    unescaped) can be specified on construction.
    
    
    For details on escaping URIs for use in web pages, see section 2.4 of <a
    href="http://www.ietf.org/rfc/rfc3986.txt">RFC 3986</a>.
    
    
    In most cases this class should not need to be used directly. If you have no
    special requirements for escaping your URIs, you should use either
    CharEscapers.uriEscaper() or CharEscapers.uriEscaper(boolean).
    
    
    When encoding a String, the following rules apply:
    
    - The alphanumeric characters "a" through "z", "A" through "Z" and "0"
    through "9" remain the same.
    - Any additionally specified safe characters remain the same.
    - If `plusForSpace` was specified, the space character " " is
    converted into a plus sign "+".
    - All other characters are converted into one or more bytes using UTF-8
    encoding and each byte is then represented by the 3-character string "%XY",
    where "XY" is the two-digit, uppercase, hexadecimal representation of the
    byte value.
    
    
    
    RFC 2396 specifies the set of unreserved characters as "-", "_", ".", "!",
    "~", "*", "'", "(" and ")". It goes on to state:
    
    
    *Unreserved characters can be escaped without changing the semantics of the
    URI, but this should not be done unless the URI is being used in a context
    that does not allow the unescaped character to appear.*
    
    
    For performance reasons the only currently supported character encoding of
    this class is UTF-8.
    
    
    **Note**: This escaper produces uppercase hexidecimal sequences. From <a
    href="http://www.ietf.org/rfc/rfc3986.txt">RFC 3986</a>:
    *"URI producers and normalizers should use uppercase hexadecimal digits for
    all percent-encodings."*
    """

    SAFECHARS_URLENCODER = "-_.*"
    """
    A string of safe characters that mimics the behavior of
    java.net.URLEncoder.
    """
    SAFEPATHCHARS_URLENCODER = "-_.!~*'()@:$&,;="
    """
    A string of characters that do not need to be encoded when used in URI
    path segments, as specified in RFC 3986. Note that some of these
    characters do need to be escaped when used in other parts of the URI.
    """
    SAFEQUERYSTRINGCHARS_URLENCODER = "-_.!~*'()@:$,;/?:"
    """
    A string of characters that do not need to be encoded when used in URI
    query strings, as specified in RFC 3986. Note that some of these
    characters do need to be escaped when used in other parts of the URI.
    """


    def __init__(self, safeChars: str, plusForSpace: bool):
        """
        Constructs a URI escaper with the specified safe characters and optional
        handling of the space character.

        Arguments
        - safeChars: a non null string specifying additional safe characters for
                   this escaper (the ranges 0..9, a..z and A..Z are always safe
                   and should not be specified here)
        - plusForSpace: True if ASCII space should be escaped to `+` rather than
                   `%20`

        Raises
        - IllegalArgumentException: if any of the parameters were invalid
        """
        ...


    def escape(self, s: str) -> str:
        ...



"""
Python module generated from Java source file com.google.common.hash.LittleEndianByteArray

Java source file obtained from artifact guava version 31.0.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.hash import *
from com.google.common.primitives import Longs
from sun.misc import Unsafe
from typing import Any, Callable, Iterable, Tuple


class LittleEndianByteArray:
    """
    Utility functions for loading and storing values from a byte array.

    Author(s)
    - Kyle Maddison
    """





"""
Python module generated from Java source file org.bukkit.block.Biome

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from java.util import Locale
from org.bukkit import Keyed
from org.bukkit import NamespacedKey
from org.bukkit.block import *
from typing import Any, Callable, Iterable, Tuple


class Biome(Enum):
    """
    Holds all accepted Biomes in the default server
    """

    OCEAN = 0
    PLAINS = 1
    DESERT = 2
    WINDSWEPT_HILLS = 3
    FOREST = 4
    TAIGA = 5
    SWAMP = 6
    RIVER = 7
    NETHER_WASTES = 8
    THE_END = 9
    FROZEN_OCEAN = 10
    FROZEN_RIVER = 11
    SNOWY_PLAINS = 12
    MUSHROOM_FIELDS = 13
    BEACH = 14
    JUNGLE = 15
    SPARSE_JUNGLE = 16
    DEEP_OCEAN = 17
    STONY_SHORE = 18
    SNOWY_BEACH = 19
    BIRCH_FOREST = 20
    DARK_FOREST = 21
    SNOWY_TAIGA = 22
    OLD_GROWTH_PINE_TAIGA = 23
    WINDSWEPT_FOREST = 24
    SAVANNA = 25
    SAVANNA_PLATEAU = 26
    BADLANDS = 27
    WOODED_BADLANDS = 28
    SMALL_END_ISLANDS = 29
    END_MIDLANDS = 30
    END_HIGHLANDS = 31
    END_BARRENS = 32
    WARM_OCEAN = 33
    LUKEWARM_OCEAN = 34
    COLD_OCEAN = 35
    DEEP_LUKEWARM_OCEAN = 36
    DEEP_COLD_OCEAN = 37
    DEEP_FROZEN_OCEAN = 38
    THE_VOID = 39
    SUNFLOWER_PLAINS = 40
    WINDSWEPT_GRAVELLY_HILLS = 41
    FLOWER_FOREST = 42
    ICE_SPIKES = 43
    OLD_GROWTH_BIRCH_FOREST = 44
    OLD_GROWTH_SPRUCE_TAIGA = 45
    WINDSWEPT_SAVANNA = 46
    ERODED_BADLANDS = 47
    BAMBOO_JUNGLE = 48
    SOUL_SAND_VALLEY = 49
    CRIMSON_FOREST = 50
    WARPED_FOREST = 51
    BASALT_DELTAS = 52
    DRIPSTONE_CAVES = 53
    LUSH_CAVES = 54
    MEADOW = 55
    GROVE = 56
    SNOWY_SLOPES = 57
    FROZEN_PEAKS = 58
    JAGGED_PEAKS = 59
    STONY_PEAKS = 60
    CUSTOM = 61
    """
    Represents a custom Biome
    """


    def getKey(self) -> "NamespacedKey":
        ...



from .Quantiles import Quantiles
from .ToDoubleRounder import ToDoubleRounder
from .ParametricNullness import ParametricNullness
from .StatsAccumulator import StatsAccumulator
from .ElementTypesAreNonnullByDefault import ElementTypesAreNonnullByDefault
from .PairedStats import PairedStats
from .PairedStatsAccumulator import PairedStatsAccumulator
from .LongMath import LongMath
from .Stats import Stats
from .IntMath import IntMath
from .DoubleMath import DoubleMath
from .BigDecimalMath import BigDecimalMath
from .DoubleUtils import DoubleUtils
from .LinearTransformation import LinearTransformation
from .BigIntegerMath import BigIntegerMath
from .MathPreconditions import MathPreconditions


"""
Python module generated from Java source file org.bukkit.inventory.ShapelessRecipe

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from java.util import Collections
from java.util import Iterator
from org.apache.commons.lang import Validate
from org.bukkit import Keyed
from org.bukkit import Material
from org.bukkit import NamespacedKey
from org.bukkit.inventory import *
from org.bukkit.material import MaterialData
from typing import Any, Callable, Iterable, Tuple


class ShapelessRecipe(Recipe, Keyed):
    """
    Represents a shapeless recipe, where the arrangement of the ingredients on
    the crafting grid does not matter.
    """

    def __init__(self, result: "ItemStack"):
        ...


    def __init__(self, key: "NamespacedKey", result: "ItemStack"):
        """
        Create a shapeless recipe to craft the specified ItemStack. The
        constructor merely determines the result and type; to set the actual
        recipe, you'll need to call the appropriate methods.

        Arguments
        - key: the unique recipe key
        - result: The item you want the recipe to create.

        See
        - ShapelessRecipe.addIngredient(int,Material,int)
        """
        ...


    def addIngredient(self, ingredient: "MaterialData") -> "ShapelessRecipe":
        """
        Adds the specified ingredient.

        Arguments
        - ingredient: The ingredient to add.

        Returns
        - The changed recipe, so you can chain calls.
        """
        ...


    def addIngredient(self, ingredient: "Material") -> "ShapelessRecipe":
        """
        Adds the specified ingredient.

        Arguments
        - ingredient: The ingredient to add.

        Returns
        - The changed recipe, so you can chain calls.
        """
        ...


    def addIngredient(self, ingredient: "Material", rawdata: int) -> "ShapelessRecipe":
        """
        Adds the specified ingredient.

        Arguments
        - ingredient: The ingredient to add.
        - rawdata: The data value, or -1 to allow any data value.

        Returns
        - The changed recipe, so you can chain calls.

        Deprecated
        - Magic value
        """
        ...


    def addIngredient(self, count: int, ingredient: "MaterialData") -> "ShapelessRecipe":
        """
        Adds multiples of the specified ingredient.

        Arguments
        - count: How many to add (can't be more than 9!)
        - ingredient: The ingredient to add.

        Returns
        - The changed recipe, so you can chain calls.
        """
        ...


    def addIngredient(self, count: int, ingredient: "Material") -> "ShapelessRecipe":
        """
        Adds multiples of the specified ingredient.

        Arguments
        - count: How many to add (can't be more than 9!)
        - ingredient: The ingredient to add.

        Returns
        - The changed recipe, so you can chain calls.
        """
        ...


    def addIngredient(self, count: int, ingredient: "Material", rawdata: int) -> "ShapelessRecipe":
        """
        Adds multiples of the specified ingredient.

        Arguments
        - count: How many to add (can't be more than 9!)
        - ingredient: The ingredient to add.
        - rawdata: The data value, or -1 to allow any data value.

        Returns
        - The changed recipe, so you can chain calls.

        Deprecated
        - Magic value
        """
        ...


    def addIngredient(self, ingredient: "RecipeChoice") -> "ShapelessRecipe":
        ...


    def removeIngredient(self, ingredient: "RecipeChoice") -> "ShapelessRecipe":
        """
        Removes an ingredient from the list.

        Arguments
        - ingredient: The ingredient to remove

        Returns
        - The changed recipe.
        """
        ...


    def removeIngredient(self, ingredient: "Material") -> "ShapelessRecipe":
        """
        Removes an ingredient from the list. If the ingredient occurs multiple
        times, only one instance of it is removed. Only removes exact matches,
        with a data value of 0.

        Arguments
        - ingredient: The ingredient to remove

        Returns
        - The changed recipe.
        """
        ...


    def removeIngredient(self, ingredient: "MaterialData") -> "ShapelessRecipe":
        """
        Removes an ingredient from the list. If the ingredient occurs multiple
        times, only one instance of it is removed. If the data value is -1,
        only ingredients with a -1 data value will be removed.

        Arguments
        - ingredient: The ingredient to remove

        Returns
        - The changed recipe.
        """
        ...


    def removeIngredient(self, count: int, ingredient: "Material") -> "ShapelessRecipe":
        """
        Removes multiple instances of an ingredient from the list. If there are
        less instances then specified, all will be removed. Only removes exact
        matches, with a data value of 0.

        Arguments
        - count: The number of copies to remove.
        - ingredient: The ingredient to remove

        Returns
        - The changed recipe.
        """
        ...


    def removeIngredient(self, count: int, ingredient: "MaterialData") -> "ShapelessRecipe":
        """
        Removes multiple instances of an ingredient from the list. If there are
        less instances then specified, all will be removed. If the data value
        is -1, only ingredients with a -1 data value will be removed.

        Arguments
        - count: The number of copies to remove.
        - ingredient: The ingredient to remove.

        Returns
        - The changed recipe.
        """
        ...


    def removeIngredient(self, ingredient: "Material", rawdata: int) -> "ShapelessRecipe":
        """
        Removes an ingredient from the list. If the ingredient occurs multiple
        times, only one instance of it is removed. If the data value is -1,
        only ingredients with a -1 data value will be removed.

        Arguments
        - ingredient: The ingredient to remove
        - rawdata: The data value;

        Returns
        - The changed recipe.

        Deprecated
        - Magic value
        """
        ...


    def removeIngredient(self, count: int, ingredient: "Material", rawdata: int) -> "ShapelessRecipe":
        """
        Removes multiple instances of an ingredient from the list. If there are
        less instances then specified, all will be removed. If the data value
        is -1, only ingredients with a -1 data value will be removed.

        Arguments
        - count: The number of copies to remove.
        - ingredient: The ingredient to remove.
        - rawdata: The data value.

        Returns
        - The changed recipe.

        Deprecated
        - Magic value
        """
        ...


    def getResult(self) -> "ItemStack":
        """
        Get the result of this recipe.

        Returns
        - The result stack.
        """
        ...


    def getIngredientList(self) -> list["ItemStack"]:
        """
        Get the list of ingredients used for this recipe.

        Returns
        - The input list
        """
        ...


    def getChoiceList(self) -> list["RecipeChoice"]:
        ...


    def getKey(self) -> "NamespacedKey":
        ...


    def getGroup(self) -> str:
        """
        Get the group of this recipe. Recipes with the same group may be grouped
        together when displayed in the client.

        Returns
        - recipe group. An empty string denotes no group. May not be null.
        """
        ...


    def setGroup(self, group: str) -> None:
        """
        Set the group of this recipe. Recipes with the same group may be grouped
        together when displayed in the client.

        Arguments
        - group: recipe group. An empty string denotes no group. May not be
        null.
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.introspector.PropertySubstitute

Java source file obtained from artifact snakeyaml version 1.30

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.reflect import Array
from java.lang.reflect import Field
from java.lang.reflect import Method
from java.lang.reflect import Modifier
from java.util import Arrays
from org.yaml.snakeyaml.error import YAMLException
from org.yaml.snakeyaml.introspector import *
from typing import Any, Callable, Iterable, Tuple


class PropertySubstitute(Property):

    def __init__(self, name: str, type: type[Any], readMethod: str, writeMethod: str, *params: Tuple[type[Any], ...]):
        ...


    def __init__(self, name: str, type: type[Any], *params: Tuple[type[Any], ...]):
        ...


    def getActualTypeArguments(self) -> list[type[Any]]:
        ...


    def setActualTypeArguments(self, *args: Tuple[type[Any], ...]) -> None:
        ...


    def set(self, object: "Object", value: "Object") -> None:
        ...


    def get(self, object: "Object") -> "Object":
        ...


    def getAnnotations(self) -> list["Annotation"]:
        ...


    def getAnnotation(self, annotationType: type["A"]) -> "A":
        ...


    def setTargetType(self, targetType: type[Any]) -> None:
        ...


    def getName(self) -> str:
        ...


    def getType(self) -> type[Any]:
        ...


    def isReadable(self) -> bool:
        ...


    def isWritable(self) -> bool:
        ...


    def setDelegate(self, delegate: "Property") -> None:
        ...



"""
Python module generated from Java source file com.google.gson.ExclusionStrategy

Java source file obtained from artifact gson version 2.8.9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from typing import Any, Callable, Iterable, Tuple


class ExclusionStrategy:
    """
    A strategy (or policy) definition that is used to decide whether or not a field or top-level
    class should be serialized or deserialized as part of the JSON output/input. For serialization,
    if the .shouldSkipClass(Class) method returns True then that class or field type
    will not be part of the JSON output. For deserialization, if .shouldSkipClass(Class)
    returns True, then it will not be set as part of the Java object structure.
    
    The following are a few examples that shows how you can use this exclusion mechanism.
    
    <strong>Exclude fields and objects based on a particular class type:</strong>
    <pre class="code">
    private static class SpecificClassExclusionStrategy implements ExclusionStrategy {
      private final Class&lt;?&gt; excludedThisClass;
    
      public SpecificClassExclusionStrategy(Class&lt;?&gt; excludedThisClass) {
        this.excludedThisClass = excludedThisClass;
      }
    
      public boolean shouldSkipClass(Class&lt;?&gt; clazz) {
        return excludedThisClass.equals(clazz);
      }
    
      public boolean shouldSkipField(FieldAttributes f) {
        return excludedThisClass.equals(f.getDeclaredClass());
      }
    }
    ```
    
    <strong>Excludes fields and objects based on a particular annotation:</strong>
    <pre class="code">
    public &#64;interface FooAnnotation {
      // some implementation here
    }
    
    // Excludes any field (or class) that is tagged with an "&#64;FooAnnotation"
    private static class FooAnnotationExclusionStrategy implements ExclusionStrategy {
      public boolean shouldSkipClass(Class&lt;?&gt; clazz) {
        return clazz.getAnnotation(FooAnnotation.class) != null;
      }
    
      public boolean shouldSkipField(FieldAttributes f) {
        return f.getAnnotation(FooAnnotation.class) != null;
      }
    }
    ```
    
    Now if you want to configure `Gson` to use a user defined exclusion strategy, then
    the `GsonBuilder` is required. The following is an example of how you can use the
    `GsonBuilder` to configure Gson to use one of the above sample:
    <pre class="code">
    ExclusionStrategy excludeStrings = new UserDefinedExclusionStrategy(String.class);
    Gson gson = new GsonBuilder()
        .setExclusionStrategies(excludeStrings)
        .create();
    ```
    
    For certain model classes, you may only want to serialize a field, but exclude it for
    deserialization. To do that, you can write an `ExclusionStrategy` as per normal;
    however, you would register it with the
    GsonBuilder.addDeserializationExclusionStrategy(ExclusionStrategy) method.
    For example:
    <pre class="code">
    ExclusionStrategy excludeStrings = new UserDefinedExclusionStrategy(String.class);
    Gson gson = new GsonBuilder()
        .addDeserializationExclusionStrategy(excludeStrings)
        .create();
    ```

    Author(s)
    - Joel Leitch

    See
    - GsonBuilder.addSerializationExclusionStrategy(ExclusionStrategy)

    Since
    - 1.4
    """

    def shouldSkipField(self, f: "FieldAttributes") -> bool:
        """
        Arguments
        - f: the field object that is under test

        Returns
        - True if the field should be ignored; otherwise False
        """
        ...


    def shouldSkipClass(self, clazz: type[Any]) -> bool:
        """
        Arguments
        - clazz: the class object that is under test

        Returns
        - True if the class should be ignored; otherwise False
        """
        ...



from .CollectionNode import CollectionNode
from .MappingNode import MappingNode
from .NodeId import NodeId
from .Tag import Tag
from .NodeTuple import NodeTuple
from .ScalarNode import ScalarNode
from .SequenceNode import SequenceNode
from .Node import Node
from .AnchorNode import AnchorNode


"""
Python module generated from Java source file com.google.common.hash.ImmutableSupplier

Java source file obtained from artifact guava version 31.0.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Supplier
from com.google.common.hash import *
from com.google.errorprone.annotations import Immutable
from typing import Any, Callable, Iterable, Tuple


class ImmutableSupplier(Supplier):





from .SafeConstructor import SafeConstructor
from .Constructor import Constructor
from .DuplicateKeyException import DuplicateKeyException
from .ConstructorException import ConstructorException
from .AbstractConstruct import AbstractConstruct
from .CustomClassLoaderConstructor import CustomClassLoaderConstructor
from .Construct import Construct
from .BaseConstructor import BaseConstructor


from .LongAddables import LongAddables
from .RemovalListeners import RemovalListeners
from .ForwardingLoadingCache import ForwardingLoadingCache
from .Cache import Cache
from .ReferenceEntry import ReferenceEntry
from .RemovalNotification import RemovalNotification
from .AbstractCache import AbstractCache
from .ParametricNullness import ParametricNullness
from .Weigher import Weigher
from .CacheLoader import CacheLoader
from .RemovalListener import RemovalListener
from .LongAdder import LongAdder
from .AbstractLoadingCache import AbstractLoadingCache
from .ElementTypesAreNonnullByDefault import ElementTypesAreNonnullByDefault
from .CacheBuilderSpec import CacheBuilderSpec
from .LongAddable import LongAddable
from .RemovalCause import RemovalCause
from .CacheBuilder import CacheBuilder
from .LoadingCache import LoadingCache
from .Striped64 import Striped64
from .LocalCache import LocalCache
from .ForwardingCache import ForwardingCache
from .CacheStats import CacheStats


from .SequenceStartEvent import SequenceStartEvent
from .CollectionStartEvent import CollectionStartEvent
from .DocumentEndEvent import DocumentEndEvent
from .CollectionEndEvent import CollectionEndEvent
from .StreamStartEvent import StreamStartEvent
from .AliasEvent import AliasEvent
from .MappingStartEvent import MappingStartEvent
from .ImplicitTuple import ImplicitTuple
from .MappingEndEvent import MappingEndEvent
from .DocumentStartEvent import DocumentStartEvent
from .CommentEvent import CommentEvent
from .StreamEndEvent import StreamEndEvent
from .Event import Event
from .ScalarEvent import ScalarEvent
from .SequenceEndEvent import SequenceEndEvent
from .NodeEvent import NodeEvent


from .Reflection import Reflection
from .Invokable import Invokable
from .ImmutableTypeToInstanceMap import ImmutableTypeToInstanceMap
from .AbstractInvocationHandler import AbstractInvocationHandler
from .ParametricNullness import ParametricNullness
from .TypeResolver import TypeResolver
from .TypeToken import TypeToken
from .Types import Types
from .TypeVisitor import TypeVisitor
from .TypeToInstanceMap import TypeToInstanceMap
from .TypeParameter import TypeParameter
from .ElementTypesAreNonnullByDefault import ElementTypesAreNonnullByDefault
from .MutableTypeToInstanceMap import MutableTypeToInstanceMap
from .ClassPath import ClassPath
from .Parameter import Parameter
from .TypeCapture import TypeCapture


"""
Python module generated from Java source file org.bukkit.BanList

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from java.util import Date
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class BanList:
    """
    A ban list, containing bans of some Type.
    """

    def getBanEntry(self, target: str) -> "BanEntry":
        """
        Gets a BanEntry by target.

        Arguments
        - target: entry parameter to search for

        Returns
        - the corresponding entry, or null if none found
        """
        ...


    def addBan(self, target: str, reason: str, expires: "Date", source: str) -> "BanEntry":
        """
        Adds a ban to the this list. If a previous ban exists, this will
        update the previous entry.

        Arguments
        - target: the target of the ban
        - reason: reason for the ban, null indicates implementation default
        - expires: date for the ban's expiration (unban), or null to imply
            forever
        - source: source of the ban, null indicates implementation default

        Returns
        - the entry for the newly created ban, or the entry for the
            (updated) previous ban
        """
        ...


    def getBanEntries(self) -> set["BanEntry"]:
        """
        Gets a set containing every BanEntry in this list.

        Returns
        - an immutable set containing every entry tracked by this list
        """
        ...


    def isBanned(self, target: str) -> bool:
        """
        Gets if a BanEntry exists for the target, indicating an active
        ban status.

        Arguments
        - target: the target to find

        Returns
        - True if a BanEntry exists for the name, indicating an
            active ban status, False otherwise
        """
        ...


    def pardon(self, target: str) -> None:
        """
        Removes the specified target from this list, therefore indicating a
        "not banned" status.

        Arguments
        - target: the target to remove from this list
        """
        ...


    class Type(Enum):
        """
        Represents a ban-type that a BanList may track.
        """

        NAME = 0
        """
        Banned player names
        """
        IP = 1
        """
        Banned player IP addresses
        """



from .CommentToken import CommentToken
from .FlowMappingStartToken import FlowMappingStartToken
from .DocumentStartToken import DocumentStartToken
from .StreamStartToken import StreamStartToken
from .BlockEndToken import BlockEndToken
from .Token import Token
from .FlowSequenceEndToken import FlowSequenceEndToken
from .DocumentEndToken import DocumentEndToken
from .WhitespaceToken import WhitespaceToken
from .FlowSequenceStartToken import FlowSequenceStartToken
from .ScalarToken import ScalarToken
from .DirectiveToken import DirectiveToken
from .FlowMappingEndToken import FlowMappingEndToken
from .BlockSequenceStartToken import BlockSequenceStartToken
from .BlockMappingStartToken import BlockMappingStartToken
from .TagToken import TagToken
from .AliasToken import AliasToken
from .KeyToken import KeyToken
from .StreamEndToken import StreamEndToken
from .FlowEntryToken import FlowEntryToken
from .ValueToken import ValueToken
from .TagTuple import TagTuple
from .AnchorToken import AnchorToken
from .BlockEntryToken import BlockEntryToken


"""
Python module generated from Java source file org.bukkit.Registry

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Predicates
from com.google.common.collect import ImmutableMap
from java.util import Arrays
from java.util import Iterator
from java.util.function import Predicate
from org.bukkit import *
from org.bukkit.advancement import Advancement
from org.bukkit.attribute import Attribute
from org.bukkit.block import Biome
from org.bukkit.boss import KeyedBossBar
from org.bukkit.enchantments import Enchantment
from org.bukkit.entity import EntityType
from org.bukkit.entity import Villager
from org.bukkit.entity.memory import MemoryKey
from org.bukkit.loot import LootTables
from typing import Any, Callable, Iterable, Tuple


class Registry(Iterable):
    """
    Represents a registry of Bukkit objects that may be retrieved by
    NamespacedKey.
    
    Type `<T>`: type of item in the registry
    """

    ADVANCEMENT = Registry<Advancement>() {
    
        @Nullable
        @Override
        public Advancement get(@NotNull NamespacedKey key) {
            return Bukkit.getAdvancement(key);
        }
    
        @NotNull
        @Override
        public Iterator<Advancement> iterator() {
            return Bukkit.advancementIterator();
        }
    }
    """
    Server advancements.

    See
    - Bukkit.advancementIterator()
    """
    ART = SimpleRegistry<>(Art.class)
    """
    Server art.

    See
    - Art
    """
    ATTRIBUTE = SimpleRegistry<>(Attribute.class)
    """
    Attribute.

    See
    - Attribute
    """
    BIOME = SimpleRegistry<>(Biome.class)
    """
    Server biomes.

    See
    - Biome
    """
    BOSS_BARS = Registry<KeyedBossBar>() {
    
        @Nullable
        @Override
        public KeyedBossBar get(@NotNull NamespacedKey key) {
            return Bukkit.getBossBar(key);
        }
    
        @NotNull
        @Override
        public Iterator<KeyedBossBar> iterator() {
            return Bukkit.getBossBars();
        }
    }
    """
    Custom boss bars.

    See
    - Bukkit.getBossBars()
    """
    ENCHANTMENT = Registry<Enchantment>() {
    
        @Nullable
        @Override
        public Enchantment get(@NotNull NamespacedKey key) {
            return Enchantment.getByKey(key);
        }
    
        @NotNull
        @Override
        public Iterator<Enchantment> iterator() {
            return Arrays.asList(Enchantment.values()).iterator();
        }
    }
    """
    Server enchantments.

    See
    - Enchantment.getByKey(org.bukkit.NamespacedKey)
    """
    ENTITY_TYPE = SimpleRegistry<>(EntityType.class, (entity) -> entity != EntityType.UNKNOWN)
    """
    Server entity types.

    See
    - EntityType
    """
    LOOT_TABLES = SimpleRegistry<>(LootTables.class)
    """
    Default server loot tables.

    See
    - LootTables
    """
    MATERIAL = SimpleRegistry<>(Material.class, (mat) -> !mat.isLegacy())
    """
    Server materials.

    See
    - Material
    """
    STATISTIC = SimpleRegistry<>(Statistic.class)
    """
    Server statistics.

    See
    - Statistic
    """
    SOUNDS = SimpleRegistry<>(Sound.class)
    """
    Sound keys.

    See
    - Sound
    """
    VILLAGER_PROFESSION = SimpleRegistry<>(Villager.Profession.class)
    """
    Villager profession.

    See
    - Villager.Profession
    """
    VILLAGER_TYPE = SimpleRegistry<>(Villager.Type.class)
    """
    Villager type.

    See
    - Villager.Type
    """
    MEMORY_MODULE_TYPE = Registry<MemoryKey>() {
    
        @NotNull
        @Override
        public Iterator iterator() {
            return MemoryKey.values().iterator();
        }
    
        @Nullable
        @Override
        public MemoryKey get(@NotNull NamespacedKey key) {
            return MemoryKey.getByKey(key);
        }
    }
    """
    Memory Keys.

    See
    - MemoryKey
    """
    FLUID = SimpleRegistry<>(Fluid.class)
    """
    Server fluids.

    See
    - Fluid
    """
    GAME_EVENT = Registry<GameEvent>() {
    
        @NotNull
        @Override
        public Iterator iterator() {
            return GameEvent.values().iterator();
        }
    
        @Nullable
        @Override
        public GameEvent get(@NotNull NamespacedKey key) {
            return GameEvent.getByKey(key);
        }
    }
    """
    Game events.

    See
    - GameEvent
    """


    def get(self, key: "NamespacedKey") -> "T":
        """
        Get the object by its key.

        Arguments
        - key: non-null key

        Returns
        - item or null if does not exist
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.DumperOptions

Java source file obtained from artifact snakeyaml version 1.30

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from java.util import TimeZone
from org.yaml.snakeyaml import *
from org.yaml.snakeyaml.emitter import Emitter
from org.yaml.snakeyaml.error import YAMLException
from org.yaml.snakeyaml.serializer import AnchorGenerator
from org.yaml.snakeyaml.serializer import NumberAnchorGenerator
from typing import Any, Callable, Iterable, Tuple


class DumperOptions:

    def isAllowUnicode(self) -> bool:
        ...


    def setAllowUnicode(self, allowUnicode: bool) -> None:
        """
        Specify whether to emit non-ASCII printable Unicode characters.
        The default value is True.
        When set to False then printable non-ASCII characters (Cyrillic, Chinese etc)
        will be not printed but escaped (to support ASCII terminals)

        Arguments
        - allowUnicode: if allowUnicode is False then all non-ASCII characters are
                   escaped
        """
        ...


    def getDefaultScalarStyle(self) -> "ScalarStyle":
        ...


    def setDefaultScalarStyle(self, defaultStyle: "ScalarStyle") -> None:
        """
        Set default style for scalars. See YAML 1.1 specification, 2.3 Scalars
        (http://yaml.org/spec/1.1/#id858081)

        Arguments
        - defaultStyle: set the style for all scalars
        """
        ...


    def setIndent(self, indent: int) -> None:
        ...


    def getIndent(self) -> int:
        ...


    def setIndicatorIndent(self, indicatorIndent: int) -> None:
        """
        Set number of white spaces to use for the sequence indicator '-'

        Arguments
        - indicatorIndent: value to be used as indent
        """
        ...


    def getIndicatorIndent(self) -> int:
        ...


    def getIndentWithIndicator(self) -> bool:
        ...


    def setIndentWithIndicator(self, indentWithIndicator: bool) -> None:
        """
        Set to True to add the indent for sequences to the general indent

        Arguments
        - indentWithIndicator: - True when indent for sequences is added to general
        """
        ...


    def setVersion(self, version: "Version") -> None:
        ...


    def getVersion(self) -> "Version":
        ...


    def setCanonical(self, canonical: bool) -> None:
        """
        Force the emitter to produce a canonical YAML document.

        Arguments
        - canonical: True produce canonical YAML document
        """
        ...


    def isCanonical(self) -> bool:
        ...


    def setPrettyFlow(self, prettyFlow: bool) -> None:
        """
        Force the emitter to produce a pretty YAML document when using the flow
        style.

        Arguments
        - prettyFlow: True produce pretty flow YAML document
        """
        ...


    def isPrettyFlow(self) -> bool:
        ...


    def setWidth(self, bestWidth: int) -> None:
        """
        Specify the preferred width to emit scalars. When the scalar
        representation takes more then the preferred with the scalar will be
        split into a few lines. The default is 80.

        Arguments
        - bestWidth: the preferred width for scalars.
        """
        ...


    def getWidth(self) -> int:
        ...


    def setSplitLines(self, splitLines: bool) -> None:
        """
        Specify whether to split lines exceeding preferred width for
        scalars. The default is True.

        Arguments
        - splitLines: whether to split lines exceeding preferred width for scalars.
        """
        ...


    def getSplitLines(self) -> bool:
        ...


    def getLineBreak(self) -> "LineBreak":
        ...


    def setDefaultFlowStyle(self, defaultFlowStyle: "FlowStyle") -> None:
        ...


    def getDefaultFlowStyle(self) -> "FlowStyle":
        ...


    def setLineBreak(self, lineBreak: "LineBreak") -> None:
        """
        Specify the line break to separate the lines. It is platform specific:
        Windows - "\r\n", old MacOS - "\r", Unix - "\n". The default value is the
        one for Unix.

        Arguments
        - lineBreak: to be used for the input
        """
        ...


    def isExplicitStart(self) -> bool:
        ...


    def setExplicitStart(self, explicitStart: bool) -> None:
        ...


    def isExplicitEnd(self) -> bool:
        ...


    def setExplicitEnd(self, explicitEnd: bool) -> None:
        ...


    def getTags(self) -> dict[str, str]:
        ...


    def setTags(self, tags: dict[str, str]) -> None:
        ...


    def isAllowReadOnlyProperties(self) -> bool:
        """
        Report whether read-only JavaBean properties (the ones without setters)
        should be included in the YAML document

        Returns
        - False when read-only JavaBean properties are not emitted
        """
        ...


    def setAllowReadOnlyProperties(self, allowReadOnlyProperties: bool) -> None:
        """
        Set to True to include read-only JavaBean properties (the ones without
        setters) in the YAML document. By default these properties are not
        included to be able to parse later the same JavaBean.

        Arguments
        - allowReadOnlyProperties: - True to dump read-only JavaBean properties
        """
        ...


    def getTimeZone(self) -> "TimeZone":
        ...


    def setTimeZone(self, timeZone: "TimeZone") -> None:
        """
        Set the timezone to be used for Date. If set to `null` UTC is
        used.

        Arguments
        - timeZone: for created Dates or null to use UTC
        """
        ...


    def getAnchorGenerator(self) -> "AnchorGenerator":
        ...


    def setAnchorGenerator(self, anchorGenerator: "AnchorGenerator") -> None:
        ...


    def getMaxSimpleKeyLength(self) -> int:
        ...


    def setMaxSimpleKeyLength(self, maxSimpleKeyLength: int) -> None:
        """
        Define max key length to use simple key (without '?')
        More info https://yaml.org/spec/1.1/#id934537

        Arguments
        - maxSimpleKeyLength: - the limit after which the key gets explicit key indicator '?'
        """
        ...


    def setProcessComments(self, processComments: bool) -> None:
        ...


    def isProcessComments(self) -> bool:
        ...


    def getNonPrintableStyle(self) -> "NonPrintableStyle":
        ...


    def setNonPrintableStyle(self, style: "NonPrintableStyle") -> None:
        """
        When String contains non-printable characters SnakeYAML convert it to binary data with the !!binary tag.
        Set this to ESCAPE to keep the !!str tag and escape the non-printable chars with \\x or \\u

        Arguments
        - style: ESCAPE to force SnakeYAML to keep !!str tag for non-printable data
        """
        ...


    class ScalarStyle(Enum):
        """
        YAML provides a rich set of scalar styles. Block scalar styles include
        the literal style and the folded style; flow scalar styles include the
        plain style and two quoted styles, the single-quoted style and the
        double-quoted style. These styles offer a range of trade-offs between
        expressive power and readability.

        See
        - <a href="http://yaml.org/spec/1.1/.id858081">2.3. Scalars</a>
        """

        DOUBLE_QUOTED = ('"')
        SINGLE_QUOTED = ('\'')
        LITERAL = ('|')
        FOLDED = ('>')
        PLAIN = (None)


        def getChar(self) -> "Character":
            ...


        def toString(self) -> str:
            ...


        @staticmethod
        def createStyle(style: "Character") -> "ScalarStyle":
            ...


    class FlowStyle(Enum):
        """
        Block styles use indentation to denote nesting and scope within the
        document. In contrast, flow styles rely on explicit indicators to denote
        nesting and scope.

        See
        - <a href="http://www.yaml.org/spec/current.html.id2509255">3.2.3.1.
             Node Styles (http://yaml.org/spec/1.1)</a>
        """

        FLOW = (True)
        BLOCK = (False)
        AUTO = (None)


        @staticmethod
        def fromBoolean(flowStyle: "Boolean") -> "FlowStyle":
            ...


        def getStyleBoolean(self) -> "Boolean":
            ...


        def toString(self) -> str:
            ...


    class LineBreak(Enum):
        """
        Platform dependent line break.
        """

        WIN = ("\r\n")
        MAC = ("\r")
        UNIX = ("\n")


        def getString(self) -> str:
            ...


        def toString(self) -> str:
            ...


        @staticmethod
        def getPlatformLineBreak() -> "LineBreak":
            ...


    class Version(Enum):
        """
        Specification version. Currently supported 1.0 and 1.1
        """

        V1_0 = (Integer[] { 1, 0 })
        V1_1 = (Integer[] { 1, 1 })


        def major(self) -> int:
            ...


        def minor(self) -> int:
            ...


        def getRepresentation(self) -> str:
            ...


        def toString(self) -> str:
            ...


    class NonPrintableStyle(Enum):

        BINARY = 0
        """
        Transform String to binary if it contains non-printable characters
        """
        ESCAPE = 1
        """
        Escape non-printable characters
        """



"""
Python module generated from Java source file org.bukkit.material.Cake

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class Cake(MaterialData):
    """
    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self):
        ...


    def __init__(self, type: "Material"):
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def getSlicesEaten(self) -> int:
        """
        Gets the number of slices eaten from this cake

        Returns
        - The number of slices eaten
        """
        ...


    def getSlicesRemaining(self) -> int:
        """
        Gets the number of slices remaining on this cake

        Returns
        - The number of slices remaining
        """
        ...


    def setSlicesEaten(self, n: int) -> None:
        """
        Sets the number of slices eaten from this cake

        Arguments
        - n: The number of slices eaten
        """
        ...


    def setSlicesRemaining(self, n: int) -> None:
        """
        Sets the number of slices remaining on this cake

        Arguments
        - n: The number of slices remaining
        """
        ...


    def toString(self) -> str:
        ...


    def clone(self) -> "Cake":
        ...



"""
Python module generated from Java source file org.bukkit.scoreboard.DisplaySlot

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.scoreboard import *
from typing import Any, Callable, Iterable, Tuple


class DisplaySlot(Enum):
    """
    Locations for displaying objectives to the player
    """

    BELOW_NAME = 0
    PLAYER_LIST = 1
    SIDEBAR = 2



"""
Python module generated from Java source file com.google.gson.internal.reflect.PreJava9ReflectionAccessor

Java source file obtained from artifact gson version 2.8.9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.internal.reflect import *
from java.lang.reflect import AccessibleObject
from typing import Any, Callable, Iterable, Tuple


class PreJava9ReflectionAccessor(ReflectionAccessor):
    """
    A basic implementation of ReflectionAccessor which is suitable for Java 8 and below.
    
    This implementation just calls AccessibleObject.setAccessible(boolean) setAccessible(True), which worked
    fine before Java 9.
    """

    def makeAccessible(self, ao: "AccessibleObject") -> None:
        """

        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.ProjectileLaunchEvent

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Entity
from org.bukkit.entity import Projectile
from org.bukkit.event import Cancellable
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class ProjectileLaunchEvent(EntitySpawnEvent, Cancellable):
    """
    Called when a projectile is launched.
    """

    def __init__(self, what: "Entity"):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getEntity(self) -> "Projectile":
        ...



"""
Python module generated from Java source file com.google.gson.GsonBuilder

Java source file obtained from artifact gson version 2.8.9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from com.google.gson.internal import $Gson$Preconditions
from com.google.gson.internal import Excluder
from com.google.gson.internal.bind import DefaultDateTypeAdapter
from com.google.gson.internal.bind import TreeTypeAdapter
from com.google.gson.internal.bind import TypeAdapters
from com.google.gson.internal.sql import SqlTypesSupport
from com.google.gson.reflect import TypeToken
from com.google.gson.stream import JsonReader
from java.lang.reflect import Type
from java.text import DateFormat
from java.util import Collections
from java.util import Date
from typing import Any, Callable, Iterable, Tuple


class GsonBuilder:
    """
    Use this builder to construct a Gson instance when you need to set configuration
    options other than the default. For Gson with default configuration, it is simpler to
    use `new Gson()`. `GsonBuilder` is best used by creating it, and then invoking its
    various configuration methods, and finally calling create.
    
    The following is an example shows how to use the `GsonBuilder` to construct a Gson
    instance:
    
    ```
    Gson gson = new GsonBuilder()
        .registerTypeAdapter(Id.class, new IdTypeAdapter())
        .enableComplexMapKeySerialization()
        .serializeNulls()
        .setDateFormat(DateFormat.LONG)
        .setFieldNamingPolicy(FieldNamingPolicy.UPPER_CAMEL_CASE)
        .setPrettyPrinting()
        .setVersion(1.0)
        .create();
    ```
    
    NOTES:
    
    -  the order of invocation of configuration methods does not matter.
    -  The default serialization of Date and its subclasses in Gson does
     not contain time-zone information. So, if you are using date/time instances,
     use `GsonBuilder` and its `setDateFormat` methods.
     

    Author(s)
    - Jesse Wilson
    """

    def __init__(self):
        """
        Creates a GsonBuilder instance that can be used to build Gson with various configuration
        settings. GsonBuilder follows the builder pattern, and it is typically used by first
        invoking various configuration methods to set desired options, and finally calling
        .create().
        """
        ...


    def setVersion(self, ignoreVersionsAfter: float) -> "GsonBuilder":
        """
        Configures Gson to enable versioning support.

        Arguments
        - ignoreVersionsAfter: any field or type marked with a version higher than this value
        are ignored during serialization or deserialization.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern
        """
        ...


    def excludeFieldsWithModifiers(self, *modifiers: Tuple[int, ...]) -> "GsonBuilder":
        """
        Configures Gson to excludes all class fields that have the specified modifiers. By default,
        Gson will exclude all fields marked transient or static. This method will override that
        behavior.

        Arguments
        - modifiers: the field modifiers. You must use the modifiers specified in the
        java.lang.reflect.Modifier class. For example,
        java.lang.reflect.Modifier.TRANSIENT,
        java.lang.reflect.Modifier.STATIC.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern
        """
        ...


    def generateNonExecutableJson(self) -> "GsonBuilder":
        """
        Makes the output JSON non-executable in Javascript by prefixing the generated JSON with some
        special text. This prevents attacks from third-party sites through script sourcing. See
        <a href="http://code.google.com/p/google-gson/issues/detail?id=42">Gson Issue 42</a>
        for details.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.3
        """
        ...


    def excludeFieldsWithoutExposeAnnotation(self) -> "GsonBuilder":
        """
        Configures Gson to exclude all fields from consideration for serialization or deserialization
        that do not have the com.google.gson.annotations.Expose annotation.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern
        """
        ...


    def serializeNulls(self) -> "GsonBuilder":
        """
        Configure Gson to serialize null fields. By default, Gson omits all fields that are null
        during serialization.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.2
        """
        ...


    def enableComplexMapKeySerialization(self) -> "GsonBuilder":
        """
        Enabling this feature will only change the serialized form if the map key is
        a complex type (i.e. non-primitive) in its <strong>serialized</strong> JSON
        form. The default implementation of map serialization uses `toString()`
        on the key; however, when this is called then one of the following cases
        apply:
        
        <h3>Maps as JSON objects</h3>
        For this case, assume that a type adapter is registered to serialize and
        deserialize some `Point` class, which contains an x and y coordinate,
        to/from the JSON Primitive string value `"(x,y)"`. The Java map would
        then be serialized as a JsonObject.
        
        Below is an example:
        ```  `Gson gson = new GsonBuilder()
              .register(Point.class, new MyPointTypeAdapter())
              .enableComplexMapKeySerialization()
              .create();
        
          Map<Point, String> original = new LinkedHashMap<Point, String>();
          original.put(new Point(5, 6), "a");
          original.put(new Point(8, 8), "b");
          System.out.println(gson.toJson(original, type));````
        The above code prints this JSON object:```  `{
            "(5,6)": "a",
            "(8,8)": "b"`
        }```
        
        <h3>Maps as JSON arrays</h3>
        For this case, assume that a type adapter was NOT registered for some
        `Point` class, but rather the default Gson serialization is applied.
        In this case, some `new Point(2,3)` would serialize as `{"x":2,"y":5`}.
        
        Given the assumption above, a `Map<Point, String>` will be
        serialize as an array of arrays (can be viewed as an entry set of pairs).
        
        Below is an example of serializing complex types as JSON arrays:
        ``` `Gson gson = new GsonBuilder()
              .enableComplexMapKeySerialization()
              .create();
        
          Map<Point, String> original = new LinkedHashMap<Point, String>();
          original.put(new Point(5, 6), "a");
          original.put(new Point(8, 8), "b");
          System.out.println(gson.toJson(original, type));`
        
        The JSON output would look as follows:
        ```   `[
            [
              {
                "x": 5,
                "y": 6`,
              "a"
            ],
            [
              {
                "x": 8,
                "y": 8
              },
              "b"
            ]
          ]
        }```

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.7
        """
        ...


    def disableInnerClassSerialization(self) -> "GsonBuilder":
        """
        Configures Gson to exclude inner classes during serialization.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.3
        """
        ...


    def setLongSerializationPolicy(self, serializationPolicy: "LongSerializationPolicy") -> "GsonBuilder":
        """
        Configures Gson to apply a specific serialization policy for `Long` and `long`
        objects.

        Arguments
        - serializationPolicy: the particular policy to use for serializing longs.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.3
        """
        ...


    def setFieldNamingPolicy(self, namingConvention: "FieldNamingPolicy") -> "GsonBuilder":
        """
        Configures Gson to apply a specific naming policy to an object's field during serialization
        and deserialization.

        Arguments
        - namingConvention: the JSON field naming convention to use for serialization and
        deserialization.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern
        """
        ...


    def setFieldNamingStrategy(self, fieldNamingStrategy: "FieldNamingStrategy") -> "GsonBuilder":
        """
        Configures Gson to apply a specific naming policy strategy to an object's field during
        serialization and deserialization.

        Arguments
        - fieldNamingStrategy: the actual naming strategy to apply to the fields

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.3
        """
        ...


    def setObjectToNumberStrategy(self, objectToNumberStrategy: "ToNumberStrategy") -> "GsonBuilder":
        """
        Configures Gson to apply a specific number strategy during deserialization of Object.

        Arguments
        - objectToNumberStrategy: the actual object-to-number strategy

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        See
        - ToNumberPolicy.DOUBLE The default object-to-number strategy
        """
        ...


    def setNumberToNumberStrategy(self, numberToNumberStrategy: "ToNumberStrategy") -> "GsonBuilder":
        """
        Configures Gson to apply a specific number strategy during deserialization of Number.

        Arguments
        - numberToNumberStrategy: the actual number-to-number strategy

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        See
        - ToNumberPolicy.LAZILY_PARSED_NUMBER The default number-to-number strategy
        """
        ...


    def setExclusionStrategies(self, *strategies: Tuple["ExclusionStrategy", ...]) -> "GsonBuilder":
        """
        Configures Gson to apply a set of exclusion strategies during both serialization and
        deserialization. Each of the `strategies` will be applied as a disjunction rule.
        This means that if one of the `strategies` suggests that a field (or class) should be
        skipped then that field (or object) is skipped during serialization/deserialization.

        Arguments
        - strategies: the set of strategy object to apply during object (de)serialization.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.4
        """
        ...


    def addSerializationExclusionStrategy(self, strategy: "ExclusionStrategy") -> "GsonBuilder":
        """
        Configures Gson to apply the passed in exclusion strategy during serialization.
        If this method is invoked numerous times with different exclusion strategy objects
        then the exclusion strategies that were added will be applied as a disjunction rule.
        This means that if one of the added exclusion strategies suggests that a field (or
        class) should be skipped then that field (or object) is skipped during its
        serialization.

        Arguments
        - strategy: an exclusion strategy to apply during serialization.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.7
        """
        ...


    def addDeserializationExclusionStrategy(self, strategy: "ExclusionStrategy") -> "GsonBuilder":
        """
        Configures Gson to apply the passed in exclusion strategy during deserialization.
        If this method is invoked numerous times with different exclusion strategy objects
        then the exclusion strategies that were added will be applied as a disjunction rule.
        This means that if one of the added exclusion strategies suggests that a field (or
        class) should be skipped then that field (or object) is skipped during its
        deserialization.

        Arguments
        - strategy: an exclusion strategy to apply during deserialization.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.7
        """
        ...


    def setPrettyPrinting(self) -> "GsonBuilder":
        """
        Configures Gson to output Json that fits in a page for pretty printing. This option only
        affects Json serialization.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern
        """
        ...


    def setLenient(self) -> "GsonBuilder":
        """
        By default, Gson is strict and only accepts JSON as specified by
        <a href="http://www.ietf.org/rfc/rfc4627.txt">RFC 4627</a>. This option makes the parser
        liberal in what it accepts.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        See
        - JsonReader.setLenient(boolean)
        """
        ...


    def disableHtmlEscaping(self) -> "GsonBuilder":
        """
        By default, Gson escapes HTML characters such as &lt; &gt; etc. Use this option to configure
        Gson to pass-through HTML characters as is.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.3
        """
        ...


    def setDateFormat(self, pattern: str) -> "GsonBuilder":
        """
        Configures Gson to serialize `Date` objects according to the pattern provided. You can
        call this method or .setDateFormat(int) multiple times, but only the last invocation
        will be used to decide the serialization format.
        
        The date format will be used to serialize and deserialize java.util.Date and in case
        the `java.sql` module is present, also java.sql.Timestamp and java.sql.Date.
        
        Note that this pattern must abide by the convention provided by `SimpleDateFormat`
        class. See the documentation in java.text.SimpleDateFormat for more information on
        valid date and time patterns.

        Arguments
        - pattern: the pattern that dates will be serialized/deserialized to/from

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.2
        """
        ...


    def setDateFormat(self, style: int) -> "GsonBuilder":
        """
        Configures Gson to to serialize `Date` objects according to the style value provided.
        You can call this method or .setDateFormat(String) multiple times, but only the last
        invocation will be used to decide the serialization format.
        
        Note that this style value should be one of the predefined constants in the
        `DateFormat` class. See the documentation in java.text.DateFormat for more
        information on the valid style constants.

        Arguments
        - style: the predefined date style that date objects will be serialized/deserialized
        to/from

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.2
        """
        ...


    def setDateFormat(self, dateStyle: int, timeStyle: int) -> "GsonBuilder":
        """
        Configures Gson to to serialize `Date` objects according to the style value provided.
        You can call this method or .setDateFormat(String) multiple times, but only the last
        invocation will be used to decide the serialization format.
        
        Note that this style value should be one of the predefined constants in the
        `DateFormat` class. See the documentation in java.text.DateFormat for more
        information on the valid style constants.

        Arguments
        - dateStyle: the predefined date style that date objects will be serialized/deserialized
        to/from
        - timeStyle: the predefined style for the time portion of the date objects

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.2
        """
        ...


    def registerTypeAdapter(self, type: "Type", typeAdapter: "Object") -> "GsonBuilder":
        """
        Configures Gson for custom serialization or deserialization. This method combines the
        registration of an TypeAdapter, InstanceCreator, JsonSerializer, and a
        JsonDeserializer. It is best used when a single object `typeAdapter` implements
        all the required interfaces for custom serialization with Gson. If a type adapter was
        previously registered for the specified `type`, it is overwritten.
        
        This registers the type specified and no other types: you must manually register related
        types! For example, applications registering `boolean.class` should also register `Boolean.class`.

        Arguments
        - type: the type definition for the type adapter being registered
        - typeAdapter: This object must implement at least one of the TypeAdapter,
        InstanceCreator, JsonSerializer, and a JsonDeserializer interfaces.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern
        """
        ...


    def registerTypeAdapterFactory(self, factory: "TypeAdapterFactory") -> "GsonBuilder":
        """
        Register a factory for type adapters. Registering a factory is useful when the type
        adapter needs to be configured based on the type of the field being processed. Gson
        is designed to handle a large number of factories, so you should consider registering
        them to be at par with registering an individual type adapter.

        Since
        - 2.1
        """
        ...


    def registerTypeHierarchyAdapter(self, baseType: type[Any], typeAdapter: "Object") -> "GsonBuilder":
        """
        Configures Gson for custom serialization or deserialization for an inheritance type hierarchy.
        This method combines the registration of a TypeAdapter, JsonSerializer and
        a JsonDeserializer. If a type adapter was previously registered for the specified
        type hierarchy, it is overridden. If a type adapter is registered for a specific type in
        the type hierarchy, it will be invoked instead of the one registered for the type hierarchy.

        Arguments
        - baseType: the class definition for the type adapter being registered for the base class
               or interface
        - typeAdapter: This object must implement at least one of TypeAdapter,
               JsonSerializer or JsonDeserializer interfaces.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.7
        """
        ...


    def serializeSpecialFloatingPointValues(self) -> "GsonBuilder":
        """
        Section 2.4 of <a href="http://www.ietf.org/rfc/rfc4627.txt">JSON specification</a> disallows
        special double values (NaN, Infinity, -Infinity). However,
        <a href="http://www.ecma-international.org/publications/files/ECMA-ST/Ecma-262.pdf">Javascript
        specification</a> (see section 4.3.20, 4.3.22, 4.3.23) allows these values as valid Javascript
        values. Moreover, most JavaScript engines will accept these special values in JSON without
        problem. So, at a practical level, it makes sense to accept these values as valid JSON even
        though JSON specification disallows them.
        
        Gson always accepts these special values during deserialization. However, it outputs
        strictly compliant JSON. Hence, if it encounters a float value Float.NaN,
        Float.POSITIVE_INFINITY, Float.NEGATIVE_INFINITY, or a double value
        Double.NaN, Double.POSITIVE_INFINITY, Double.NEGATIVE_INFINITY, it
        will throw an IllegalArgumentException. This method provides a way to override the
        default behavior when you know that the JSON receiver will be able to handle these special
        values.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.3
        """
        ...


    def create(self) -> "Gson":
        """
        Creates a Gson instance based on the current configuration. This method is free of
        side-effects to this `GsonBuilder` instance and hence can be called multiple times.

        Returns
        - an instance of Gson configured with the options currently set in this builder
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.EntityPortalEnterEvent

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Location
from org.bukkit.entity import Entity
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityPortalEnterEvent(EntityEvent):
    """
    Called when an entity comes into contact with a portal
    """

    def __init__(self, entity: "Entity", location: "Location"):
        ...


    def getLocation(self) -> "Location":
        """
        Gets the portal block the entity is touching

        Returns
        - The portal block the entity is touching
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.base.Optional

Java source file obtained from artifact guava version 31.0.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.annotations import GwtCompatible
from com.google.common.base import *
from com.google.errorprone.annotations import DoNotMock
from java.io import Serializable
from java.util import Iterator
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class Optional(Serializable):
    """
    An immutable object that may contain a non-null reference to another object. Each instance of
    this type either contains a non-null reference, or contains nothing (in which case we say that
    the reference is "absent"); it is never said to "contain `null`".
    
    A non-null `Optional<T>` reference can be used as a replacement for a nullable `T`
    reference. It allows you to represent "a `T` that must be present" and a "a `T` that
    might be absent" as two distinct types in your program, which can aid clarity.
    
    Some uses of this class include
    
    
      - As a method return type, as an alternative to returning `null` to indicate that no
          value was available
      - To distinguish between "unknown" (for example, not present in a map) and "known to have no
          value" (present in the map, with value `Optional.absent()`)
      - To wrap nullable references for storage in a collection that does not support `null`
          (though there are <a
          href="https://github.com/google/guava/wiki/LivingWithNullHostileCollections">several other
          approaches to this</a> that should be considered first)
    
    
    A common alternative to using this class is to find or create a suitable <a
    href="http://en.wikipedia.org/wiki/Null_Object_pattern">null object</a> for the type in question.
    
    This class is not intended as a direct analogue of any existing "option" or "maybe" construct
    from other programming environments, though it may bear some similarities.
    
    **Comparison to `java.util.Optional` (JDK 8 and higher):** A new `Optional`
    class was added for Java 8. The two classes are extremely similar, but incompatible (they cannot
    share a common supertype). *All* known differences are listed either here or with the
    relevant methods below.
    
    
      - This class is serializable; `java.util.Optional` is not.
      - `java.util.Optional` has the additional methods `ifPresent`, `filter`,
          `flatMap`, and `orElseThrow`.
      - `java.util` offers the primitive-specialized versions `OptionalInt`, `OptionalLong` and `OptionalDouble`, the use of which is recommended; Guava does not
          have these.
    
    
    **There are no plans to deprecate this class in the foreseeable future.** However, we do
    gently recommend that you prefer the new, standard Java class whenever possible.
    
    See the Guava User Guide article on <a
    href="https://github.com/google/guava/wiki/UsingAndAvoidingNullExplained#optional">using `Optional`</a>.
    
    Type `<T>`: the type of instance that can be contained. `Optional` is naturally covariant on
        this type, so it is safe to cast an `Optional<T>` to `Optional<S>` for any
        supertype `S` of `T`.

    Author(s)
    - Kevin Bourrillion

    Since
    - 10.0
    """

    @staticmethod
    def absent() -> "Optional"["T"]:
        """
        Returns an `Optional` instance with no contained reference.
        
        **Comparison to `java.util.Optional`:** this method is equivalent to Java 8's
        `Optional.empty`.
        """
        ...


    @staticmethod
    def of(reference: "T") -> "Optional"["T"]:
        """
        Returns an `Optional` instance containing the given non-null reference. To have `null` treated as .absent, use .fromNullable instead.
        
        **Comparison to `java.util.Optional`:** no differences.

        Raises
        - NullPointerException: if `reference` is null
        """
        ...


    @staticmethod
    def fromNullable(nullableReference: "T") -> "Optional"["T"]:
        """
        If `nullableReference` is non-null, returns an `Optional` instance containing that
        reference; otherwise returns Optional.absent.
        
        **Comparison to `java.util.Optional`:** this method is equivalent to Java 8's
        `Optional.ofNullable`.
        """
        ...


    @staticmethod
    def fromJavaUtil(javaUtilOptional: "java.util.Optional"["T"]) -> "Optional"["T"]:
        """
        Returns the equivalent `com.google.common.base.Optional` value to the given `java.util.Optional`, or `null` if the argument is null.

        Since
        - 21.0
        """
        ...


    @staticmethod
    def toJavaUtil(googleOptional: "Optional"["T"]) -> "java.util.Optional"["T"]:
        """
        Returns the equivalent `java.util.Optional` value to the given `com.google.common.base.Optional`, or `null` if the argument is null.
        
        If `googleOptional` is known to be non-null, use `googleOptional.toJavaUtil()`
        instead.
        
        Unfortunately, the method reference `Optional::toJavaUtil` will not work, because it
        could refer to either the static or instance version of this method. Write out the lambda
        expression `o -> Optional.toJavaUtil(o)` instead.

        Since
        - 21.0
        """
        ...


    def toJavaUtil(self) -> "java.util.Optional"["T"]:
        """
        Returns the equivalent `java.util.Optional` value to this optional.
        
        Unfortunately, the method reference `Optional::toJavaUtil` will not work, because it
        could refer to either the static or instance version of this method. Write out the lambda
        expression `o -> o.toJavaUtil()` instead.

        Since
        - 21.0
        """
        ...


    def isPresent(self) -> bool:
        """
        Returns `True` if this holder contains a (non-null) instance.
        
        **Comparison to `java.util.Optional`:** no differences.
        """
        ...


    def get(self) -> "T":
        """
        Returns the contained instance, which must be present. If the instance might be absent, use
        .or(Object) or .orNull instead.
        
        **Comparison to `java.util.Optional`:** when the value is absent, this method
        throws IllegalStateException, whereas the Java 8 counterpart throws java.util.NoSuchElementException NoSuchElementException.

        Raises
        - IllegalStateException: if the instance is absent (.isPresent returns `False`); depending on this *specific* exception type (over the more general RuntimeException) is discouraged
        """
        ...


    def or(self, defaultValue: "T") -> "T":
        """
        Returns the contained instance if it is present; `defaultValue` otherwise. If no default
        value should be required because the instance is known to be present, use .get()
        instead. For a default value of `null`, use .orNull.
        
        Note about generics: The signature `public T or(T defaultValue)` is overly
        restrictive. However, the ideal signature, `public <S super T> S or(S)`, is not legal
        Java. As a result, some sensible operations involving subtypes are compile errors:
        
        ````Optional<Integer> optionalInt = getSomeOptionalInt();
        Number value = optionalInt.or(0.5); // error
        
        FluentIterable<? extends Number> numbers = getSomeNumbers();
        Optional<? extends Number> first = numbers.first();
        Number value = first.or(0.5); // error````
        
        As a workaround, it is always safe to cast an `Optional<? extends T>` to `Optional<T>`. Casting either of the above example `Optional` instances to `Optional<Number>` (where `Number` is the desired output type) solves the problem:
        
        ````Optional<Number> optionalInt = (Optional) getSomeOptionalInt();
        Number value = optionalInt.or(0.5); // fine
        
        FluentIterable<? extends Number> numbers = getSomeNumbers();
        Optional<Number> first = (Optional) numbers.first();
        Number value = first.or(0.5); // fine````
        
        **Comparison to `java.util.Optional`:** this method is similar to Java 8's `Optional.orElse`, but will not accept `null` as a `defaultValue` (.orNull
        must be used instead). As a result, the value returned by this method is guaranteed non-null,
        which is not the case for the `java.util` equivalent.
        """
        ...


    def or(self, secondChoice: "Optional"["T"]) -> "Optional"["T"]:
        """
        Returns this `Optional` if it has a value present; `secondChoice` otherwise.
        
        **Comparison to `java.util.Optional`:** this method has no equivalent in Java 8's
        `Optional` class; write `thisOptional.isPresent() ? thisOptional : secondChoice`
        instead.
        """
        ...


    def or(self, supplier: "Supplier"["T"]) -> "T":
        """
        Returns the contained instance if it is present; `supplier.get()` otherwise.
        
        **Comparison to `java.util.Optional`:** this method is similar to Java 8's `Optional.orElseGet`, except when `supplier` returns `null`. In this case this
        method throws an exception, whereas the Java 8 method returns the `null` to the caller.

        Raises
        - NullPointerException: if this optional's value is absent and the supplier returns `null`
        """
        ...


    def orNull(self) -> "T":
        """
        Returns the contained instance if it is present; `null` otherwise. If the instance is
        known to be present, use .get() instead.
        
        **Comparison to `java.util.Optional`:** this method is equivalent to Java 8's
        `Optional.orElse(null)`.
        """
        ...


    def asSet(self) -> set["T"]:
        """
        Returns an immutable singleton Set whose only element is the contained instance if it
        is present; an empty immutable Set otherwise.
        
        **Comparison to `java.util.Optional`:** this method has no equivalent in Java 8's
        `Optional` class. However, this common usage:
        
        ````for (Foo foo : possibleFoo.asSet()) {
          doSomethingWith(foo);`
        }```
        
        ... can be replaced with:
        
        ````possibleFoo.ifPresent(foo -> doSomethingWith(foo));````
        
        **Java 9 users:** some use cases can be written with calls to `optional.stream()`.

        Since
        - 11.0
        """
        ...


    def transform(self, function: "Function"["T", "V"]) -> "Optional"["V"]:
        """
        If the instance is present, it is transformed with the given Function; otherwise,
        Optional.absent is returned.
        
        **Comparison to `java.util.Optional`:** this method is similar to Java 8's `Optional.map`, except when `function` returns `null`. In this case this method
        throws an exception, whereas the Java 8 method returns `Optional.absent()`.

        Raises
        - NullPointerException: if the function returns `null`

        Since
        - 12.0
        """
        ...


    def equals(self, object: "Object") -> bool:
        """
        Returns `True` if `object` is an `Optional` instance, and either the
        contained references are Object.equals equal to each other or both are absent.
        Note that `Optional` instances of differing parameterized types can be equal.
        
        **Comparison to `java.util.Optional`:** no differences.
        """
        ...


    def hashCode(self) -> int:
        """
        Returns a hash code for this instance.
        
        **Comparison to `java.util.Optional`:** this class leaves the specific choice of
        hash code unspecified, unlike the Java 8 equivalent.
        """
        ...


    def toString(self) -> str:
        """
        Returns a string representation for this instance.
        
        **Comparison to `java.util.Optional`:** this class leaves the specific string
        representation unspecified, unlike the Java 8 equivalent.
        """
        ...


    @staticmethod
    def presentInstances(optionals: Iterable["Optional"["T"]]) -> Iterable["T"]:
        """
        Returns the value of each present instance from the supplied `optionals`, in order,
        skipping over occurrences of Optional.absent. Iterators are unmodifiable and are
        evaluated lazily.
        
        **Comparison to `java.util.Optional`:** this method has no equivalent in Java 8's
        `Optional` class; use `optionals.stream().filter(Optional::isPresent).map(Optional::get)` instead.
        
        **Java 9 users:** use `optionals.stream().flatMap(Optional::stream)` instead.

        Since
        - 11.0 (generics widened in 13.0)
        """
        ...



"""
Python module generated from Java source file org.bukkit.Particle

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from enum import Enum
from org.bukkit import *
from org.bukkit.block.data import BlockData
from org.bukkit.inventory import ItemStack
from org.bukkit.material import MaterialData
from typing import Any, Callable, Iterable, Tuple


class Particle(Enum):

    EXPLOSION_NORMAL = 0
    EXPLOSION_LARGE = 1
    EXPLOSION_HUGE = 2
    FIREWORKS_SPARK = 3
    WATER_BUBBLE = 4
    WATER_SPLASH = 5
    WATER_WAKE = 6
    SUSPENDED = 7
    SUSPENDED_DEPTH = 8
    CRIT = 9
    CRIT_MAGIC = 10
    SMOKE_NORMAL = 11
    SMOKE_LARGE = 12
    SPELL = 13
    SPELL_INSTANT = 14
    SPELL_MOB = 15
    SPELL_MOB_AMBIENT = 16
    SPELL_WITCH = 17
    DRIP_WATER = 18
    DRIP_LAVA = 19
    VILLAGER_ANGRY = 20
    VILLAGER_HAPPY = 21
    TOWN_AURA = 22
    NOTE = 23
    PORTAL = 24
    ENCHANTMENT_TABLE = 25
    FLAME = 26
    LAVA = 27
    CLOUD = 28
    REDSTONE = (DustOptions)
    """
    Uses Particle.DustOptions as DataType
    """
    SNOWBALL = 30
    SNOW_SHOVEL = 31
    SLIME = 32
    HEART = 33
    ITEM_CRACK = (ItemStack)
    """
    Uses ItemStack as DataType
    """
    BLOCK_CRACK = (BlockData)
    """
    Uses BlockData as DataType
    """
    BLOCK_DUST = (BlockData)
    """
    Uses BlockData as DataType
    """
    WATER_DROP = 37
    MOB_APPEARANCE = 38
    DRAGON_BREATH = 39
    END_ROD = 40
    DAMAGE_INDICATOR = 41
    SWEEP_ATTACK = 42
    FALLING_DUST = (BlockData)
    """
    Uses BlockData as DataType
    """
    TOTEM = 44
    SPIT = 45
    SQUID_INK = 46
    BUBBLE_POP = 47
    CURRENT_DOWN = 48
    BUBBLE_COLUMN_UP = 49
    NAUTILUS = 50
    DOLPHIN = 51
    SNEEZE = 52
    CAMPFIRE_COSY_SMOKE = 53
    CAMPFIRE_SIGNAL_SMOKE = 54
    COMPOSTER = 55
    FLASH = 56
    FALLING_LAVA = 57
    LANDING_LAVA = 58
    FALLING_WATER = 59
    DRIPPING_HONEY = 60
    FALLING_HONEY = 61
    LANDING_HONEY = 62
    FALLING_NECTAR = 63
    SOUL_FIRE_FLAME = 64
    ASH = 65
    CRIMSON_SPORE = 66
    WARPED_SPORE = 67
    SOUL = 68
    DRIPPING_OBSIDIAN_TEAR = 69
    FALLING_OBSIDIAN_TEAR = 70
    LANDING_OBSIDIAN_TEAR = 71
    REVERSE_PORTAL = 72
    WHITE_ASH = 73
    DUST_COLOR_TRANSITION = (DustTransition)
    """
    Uses DustTransition as DataType
    """
    VIBRATION = (Vibration)
    """
    Uses Vibration as DataType
    """
    FALLING_SPORE_BLOSSOM = 76
    SPORE_BLOSSOM_AIR = 77
    SMALL_FLAME = 78
    SNOWFLAKE = 79
    DRIPPING_DRIPSTONE_LAVA = 80
    FALLING_DRIPSTONE_LAVA = 81
    DRIPPING_DRIPSTONE_WATER = 82
    FALLING_DRIPSTONE_WATER = 83
    GLOW_SQUID_INK = 84
    GLOW = 85
    WAX_ON = 86
    WAX_OFF = 87
    ELECTRIC_SPARK = 88
    SCRAPE = 89
    BLOCK_MARKER = (BlockData)
    """
    Uses BlockData as DataType
    """
    LEGACY_BLOCK_CRACK = (MaterialData)
    """
    Uses MaterialData as DataType
    """
    LEGACY_BLOCK_DUST = (MaterialData)
    """
    Uses MaterialData as DataType
    """
    LEGACY_FALLING_DUST = (MaterialData)
    """
    Uses MaterialData as DataType
    """


    def getDataType(self) -> type[Any]:
        """
        Returns the required data type for the particle

        Returns
        - the required data type
        """
        ...


    class DustOptions:
        """
        Options which can be applied to redstone dust particles - a particle
        color and size.
        """

        def __init__(self, color: "Color", size: float):
            ...


        def getColor(self) -> "Color":
            """
            The color of the particles to be displayed.

            Returns
            - particle color
            """
            ...


        def getSize(self) -> float:
            """
            Relative size of the particle.

            Returns
            - relative particle size
            """
            ...


    class DustTransition(DustOptions):
        """
        Options which can be applied to a color transitioning dust particles.
        """

        def __init__(self, fromColor: "Color", toColor: "Color", size: float):
            ...


        def getToColor(self) -> "Color":
            """
            The final of the particles to be displayed.

            Returns
            - final particle color
            """
            ...



"""
Python module generated from Java source file com.google.common.hash.Funnels

Java source file obtained from artifact guava version 31.0.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.base import Preconditions
from com.google.common.hash import *
from java.io import OutputStream
from java.io import Serializable
from java.nio.charset import Charset
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Funnels:
    """
    Funnels for common types. All implementations are serializable.

    Author(s)
    - Dimitris Andreou

    Since
    - 11.0
    """

    @staticmethod
    def byteArrayFunnel() -> "Funnel"[list[int]]:
        """
        Returns a funnel that extracts the bytes from a `byte` array.
        """
        ...


    @staticmethod
    def unencodedCharsFunnel() -> "Funnel"["CharSequence"]:
        """
        Returns a funnel that extracts the characters from a `CharSequence`, a character at a
        time, without performing any encoding. If you need to use a specific encoding, use Funnels.stringFunnel(Charset) instead.

        Since
        - 15.0 (since 11.0 as `Funnels.stringFunnel()`.
        """
        ...


    @staticmethod
    def stringFunnel(charset: "Charset") -> "Funnel"["CharSequence"]:
        """
        Returns a funnel that encodes the characters of a `CharSequence` with the specified
        `Charset`.

        Since
        - 15.0
        """
        ...


    @staticmethod
    def integerFunnel() -> "Funnel"["Integer"]:
        """
        Returns a funnel for integers.

        Since
        - 13.0
        """
        ...


    @staticmethod
    def sequentialFunnel(elementFunnel: "Funnel"["E"]) -> "Funnel"[Iterable["E"]]:
        """
        Returns a funnel that processes an `Iterable` by funneling its elements in iteration
        order with the specified funnel. No separators are added between the elements.

        Since
        - 15.0
        """
        ...


    @staticmethod
    def longFunnel() -> "Funnel"["Long"]:
        """
        Returns a funnel for longs.

        Since
        - 13.0
        """
        ...


    @staticmethod
    def asOutputStream(sink: "PrimitiveSink") -> "OutputStream":
        """
        Wraps a `PrimitiveSink` as an OutputStream, so it is easy to Funnel.funnel
        funnel an object to a `PrimitiveSink` if there is already a way to write the contents of
        the object to an `OutputStream`.
        
        The `close` and `flush` methods of the returned `OutputStream` do nothing,
        and no method throws `IOException`.

        Since
        - 13.0
        """
        ...



"""
Python module generated from Java source file org.bukkit.potion.PotionEffectType

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Arrays
from org.apache.commons.lang import Validate
from org.bukkit import Color
from org.bukkit import Keyed
from org.bukkit import NamespacedKey
from org.bukkit.potion import *
from typing import Any, Callable, Iterable, Tuple


class PotionEffectType(Keyed):
    """
    Represents a type of potion and its effect on an entity.
    """

    SPEED = PotionEffectTypeWrapper(1, "speed")
    """
    Increases movement speed.
    """
    SLOW = PotionEffectTypeWrapper(2, "slowness")
    """
    Decreases movement speed.
    """
    FAST_DIGGING = PotionEffectTypeWrapper(3, "haste")
    """
    Increases dig speed.
    """
    SLOW_DIGGING = PotionEffectTypeWrapper(4, "mining_fatigue")
    """
    Decreases dig speed.
    """
    INCREASE_DAMAGE = PotionEffectTypeWrapper(5, "strength")
    """
    Increases damage dealt.
    """
    HEAL = PotionEffectTypeWrapper(6, "instant_health")
    """
    Heals an entity.
    """
    HARM = PotionEffectTypeWrapper(7, "instant_damage")
    """
    Hurts an entity.
    """
    JUMP = PotionEffectTypeWrapper(8, "jump_boost")
    """
    Increases jump height.
    """
    CONFUSION = PotionEffectTypeWrapper(9, "nausea")
    """
    Warps vision on the client.
    """
    REGENERATION = PotionEffectTypeWrapper(10, "regeneration")
    """
    Regenerates health.
    """
    DAMAGE_RESISTANCE = PotionEffectTypeWrapper(11, "resistance")
    """
    Decreases damage dealt to an entity.
    """
    FIRE_RESISTANCE = PotionEffectTypeWrapper(12, "fire_resistance")
    """
    Stops fire damage.
    """
    WATER_BREATHING = PotionEffectTypeWrapper(13, "water_breathing")
    """
    Allows breathing underwater.
    """
    INVISIBILITY = PotionEffectTypeWrapper(14, "invisibility")
    """
    Grants invisibility.
    """
    BLINDNESS = PotionEffectTypeWrapper(15, "blindness")
    """
    Blinds an entity.
    """
    NIGHT_VISION = PotionEffectTypeWrapper(16, "night_vision")
    """
    Allows an entity to see in the dark.
    """
    HUNGER = PotionEffectTypeWrapper(17, "hunger")
    """
    Increases hunger.
    """
    WEAKNESS = PotionEffectTypeWrapper(18, "weakness")
    """
    Decreases damage dealt by an entity.
    """
    POISON = PotionEffectTypeWrapper(19, "poison")
    """
    Deals damage to an entity over time.
    """
    WITHER = PotionEffectTypeWrapper(20, "wither")
    """
    Deals damage to an entity over time and gives the health to the
    shooter.
    """
    HEALTH_BOOST = PotionEffectTypeWrapper(21, "health_boost")
    """
    Increases the maximum health of an entity.
    """
    ABSORPTION = PotionEffectTypeWrapper(22, "absorption")
    """
    Increases the maximum health of an entity with health that cannot be
    regenerated, but is refilled every 30 seconds.
    """
    SATURATION = PotionEffectTypeWrapper(23, "saturation")
    """
    Increases the food level of an entity each tick.
    """
    GLOWING = PotionEffectTypeWrapper(24, "glowing")
    """
    Outlines the entity so that it can be seen from afar.
    """
    LEVITATION = PotionEffectTypeWrapper(25, "levitation")
    """
    Causes the entity to float into the air.
    """
    LUCK = PotionEffectTypeWrapper(26, "luck")
    """
    Loot table luck.
    """
    UNLUCK = PotionEffectTypeWrapper(27, "unluck")
    """
    Loot table unluck.
    """
    SLOW_FALLING = PotionEffectTypeWrapper(28, "slow_falling")
    """
    Slows entity fall rate.
    """
    CONDUIT_POWER = PotionEffectTypeWrapper(29, "conduit_power")
    """
    Effects granted by a nearby conduit. Includes enhanced underwater abilities.
    """
    DOLPHINS_GRACE = PotionEffectTypeWrapper(30, "dolphins_grace")
    """
    Increses underwater movement speed.
    Squee'ek uh'k kk'kkkk squeek eee'eek.
    """
    BAD_OMEN = PotionEffectTypeWrapper(31, "bad_omen")
    """
    Triggers a raid when the player enters a village.
    oof.
    """
    HERO_OF_THE_VILLAGE = PotionEffectTypeWrapper(32, "hero_of_the_village")
    """
    Reduces the cost of villager trades.
    \o/.
    """


    def createEffect(self, duration: int, amplifier: int) -> "PotionEffect":
        """
        Creates a PotionEffect from this PotionEffectType, applying duration
        modifiers and checks.

        Arguments
        - duration: time in ticks
        - amplifier: the effect's amplifier

        Returns
        - a resulting potion effect

        See
        - PotionBrewer.createEffect(PotionEffectType, int, int)
        """
        ...


    def getDurationModifier(self) -> float:
        """
        Returns the duration modifier applied to effects of this type.

        Returns
        - duration modifier

        Deprecated
        - unused, always 1.0
        """
        ...


    def getId(self) -> int:
        """
        Returns the unique ID of this type.

        Returns
        - Unique ID

        Deprecated
        - Magic value
        """
        ...


    def getKey(self) -> "NamespacedKey":
        ...


    def getName(self) -> str:
        """
        Returns the name of this effect type.

        Returns
        - The name of this effect type
        """
        ...


    def isInstant(self) -> bool:
        """
        Returns whether the effect of this type happens once, immediately.

        Returns
        - whether this type is normally instant
        """
        ...


    def getColor(self) -> "Color":
        """
        Returns the color of this effect type.

        Returns
        - the color
        """
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...


    def toString(self) -> str:
        ...


    @staticmethod
    def getByKey(key: "NamespacedKey") -> "PotionEffectType":
        """
        Gets the PotionEffectType at the specified key

        Arguments
        - key: key to fetch

        Returns
        - Resulting PotionEffectType, or null if not found
        """
        ...


    @staticmethod
    def getById(id: int) -> "PotionEffectType":
        """
        Gets the effect type specified by the unique id.

        Arguments
        - id: Unique ID to fetch

        Returns
        - Resulting type, or null if not found.

        Deprecated
        - Magic value
        """
        ...


    @staticmethod
    def getByName(name: str) -> "PotionEffectType":
        """
        Gets the effect type specified by the given name.

        Arguments
        - name: Name of PotionEffectType to fetch

        Returns
        - Resulting PotionEffectType, or null if not found.
        """
        ...


    @staticmethod
    def registerPotionEffectType(type: "PotionEffectType") -> None:
        """
        Registers an effect type with the given object.
        
        Generally not to be used from within a plugin.

        Arguments
        - type: PotionType to register
        """
        ...


    @staticmethod
    def stopAcceptingRegistrations() -> None:
        """
        Stops accepting any effect type registrations.
        """
        ...


    @staticmethod
    def values() -> list["PotionEffectType"]:
        """
        Returns an array of all the registered PotionEffectTypes.
        This array is not necessarily in any particular order.

        Returns
        - Array of types.
        """
        ...



from .CharSource import CharSource
from .Closer import Closer
from .CharStreams import CharStreams
from .ParametricNullness import ParametricNullness
from .LineReader import LineReader
from .ReaderInputStream import ReaderInputStream
from .ByteSink import ByteSink
from .LittleEndianDataOutputStream import LittleEndianDataOutputStream
from .FileWriteMode import FileWriteMode
from .ByteProcessor import ByteProcessor
from .ElementTypesAreNonnullByDefault import ElementTypesAreNonnullByDefault
from .ByteSource import ByteSource
from .LittleEndianDataInputStream import LittleEndianDataInputStream
from .LineBuffer import LineBuffer
from .InsecureRecursiveDeleteException import InsecureRecursiveDeleteException
from .MultiReader import MultiReader
from .FileBackedOutputStream import FileBackedOutputStream
from .CharSink import CharSink
from .RecursiveDeleteOption import RecursiveDeleteOption
from .AppendableWriter import AppendableWriter
from .BaseEncoding import BaseEncoding
from .MultiInputStream import MultiInputStream
from .CountingOutputStream import CountingOutputStream
from .Resources import Resources
from .CharSequenceReader import CharSequenceReader
from .LineProcessor import LineProcessor
from .ByteArrayDataInput import ByteArrayDataInput
from .Closeables import Closeables
from .MoreFiles import MoreFiles
from .Java8Compatibility import Java8Compatibility
from .ByteArrayDataOutput import ByteArrayDataOutput
from .PatternFilenameFilter import PatternFilenameFilter
from .Flushables import Flushables
from .CountingInputStream import CountingInputStream
from .Files import Files
from .ByteStreams import ByteStreams


"""
Python module generated from Java source file com.google.gson.internal.bind.util.ISO8601Utils

Java source file obtained from artifact gson version 2.8.9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.internal.bind.util import *
from java.text import ParseException
from java.text import ParsePosition
from java.util import *
from typing import Any, Callable, Iterable, Tuple


class ISO8601Utils:

    @staticmethod
    def format(date: "Date") -> str:
        """
        Format a date into 'yyyy-MM-ddThh:mm:ssZ' (default timezone, no milliseconds precision)

        Arguments
        - date: the date to format

        Returns
        - the date formatted as 'yyyy-MM-ddThh:mm:ssZ'
        """
        ...


    @staticmethod
    def format(date: "Date", millis: bool) -> str:
        """
        Format a date into 'yyyy-MM-ddThh:mm:ss[.sss]Z' (GMT timezone)

        Arguments
        - date: the date to format
        - millis: True to include millis precision otherwise False

        Returns
        - the date formatted as 'yyyy-MM-ddThh:mm:ss[.sss]Z'
        """
        ...


    @staticmethod
    def format(date: "Date", millis: bool, tz: "TimeZone") -> str:
        """
        Format date into yyyy-MM-ddThh:mm:ss[.sss][Z|[+-]hh:mm]

        Arguments
        - date: the date to format
        - millis: True to include millis precision otherwise False
        - tz: timezone to use for the formatting (UTC will produce 'Z')

        Returns
        - the date formatted as yyyy-MM-ddThh:mm:ss[.sss][Z|[+-]hh:mm]
        """
        ...


    @staticmethod
    def parse(date: str, pos: "ParsePosition") -> "Date":
        """
        Parse a date from ISO-8601 formatted string. It expects a format
        [yyyy-MM-dd|yyyyMMdd][T(hh:mm[:ss[.sss]]|hhmm[ss[.sss]])]?[Z|[+-]hh[:mm]]]

        Arguments
        - date: ISO string to parse in the appropriate format.
        - pos: The position to start parsing from, updated to where parsing stopped.

        Returns
        - the parsed date

        Raises
        - ParseException: if the date is not in the appropriate format
        """
        ...
